@@ -24,14 +24,14 @@ import java.util.TreeMap;
 
 import org.apache.commons.math.MathRuntimeException;
 
-/** 
+/**
  * Maintains a frequency distribution.
  * <p>
- * Accepts int, long, char or Comparable values.  New values added must be 
- * comparable to those that have been added, otherwise the add method will 
+ * Accepts int, long, char or Comparable values.  New values added must be
+ * comparable to those that have been added, otherwise the add method will
  * throw an IllegalArgumentException.</p>
  * <p>
- * Integer values (int, long, Integer, Long) are not distinguished by type -- 
+ * Integer values (int, long, Integer, Long) are not distinguished by type --
  * i.e. <code>addValue(Long.valueOf(2)), addValue(2), addValue(2l)</code> all have
  * the same effect (similarly for arguments to <code>getCount,</code> etc.).</p>
  * <p>
@@ -40,13 +40,13 @@ import org.apache.commons.math.MathRuntimeException;
  * to combine integral types with chars in a frequency distribution will fail.
  * </p>
  * <p>
- * The values are ordered using the default (natural order), unless a  
+ * The values are ordered using the default (natural order), unless a
  * <code>Comparator</code> is supplied in the constructor.</p>
  *
- * @version $Revision: 791733 $ $Date: 2009-07-07 03:44:52 -0400 (Tue, 07 Jul 2009) $
+ * @version $Revision: 922722 $ $Date: 2010-03-13 21:15:01 -0500 (Sat, 13 Mar 2010) $
  */
 public class Frequency implements Serializable {
-    
+
     /** Serializable version identifier */
     private static final long serialVersionUID = -3845586908418844111L;
 
@@ -59,13 +59,13 @@ public class Frequency implements Serializable {
     public Frequency() {
         freqTable = new TreeMap<Comparable<?>, Long>();
     }
-    
+
     /**
      * Constructor allowing values Comparator to be specified.
-     * 
+     *
      * @param comparator Comparator used to order values
      */
-    @SuppressWarnings("unchecked")
+    @SuppressWarnings("unchecked") // TODO is the cast OK?
     public Frequency(Comparator<?> comparator) {
         freqTable = new TreeMap<Comparable<?>, Long>((Comparator<? super Comparable<?>>) comparator);
     }
@@ -73,7 +73,7 @@ public class Frequency implements Serializable {
     /**
      * Return a string representation of this frequency
      * distribution.
-     * 
+     *
      * @return a string representation.
      */
     @Override
@@ -102,30 +102,30 @@ public class Frequency implements Serializable {
      * If other objects have already been added to this Frequency, v must
      * be comparable to those that have already been added.
      * </p>
-     * 
+     *
      * @param v the value to add.
-     * @throws IllegalArgumentException if <code>v</code> is not Comparable, 
+     * @throws IllegalArgumentException if <code>v</code> is not Comparable,
      *         or is not comparable with previous entries
      * @deprecated use {@link #addValue(Comparable)} instead
      */
     @Deprecated
     public void addValue(Object v) {
         if (v instanceof Comparable<?>){
-            addValue((Comparable<?>) v);            
+            addValue((Comparable<?>) v);
         } else {
             throw MathRuntimeException.createIllegalArgumentException(
                   "class ({0}) does not implement Comparable",
                   v.getClass().getName());
         }
     }
-    
+
     /**
      * Adds 1 to the frequency count for v.
      * <p>
      * If other objects have already been added to this Frequency, v must
      * be comparable to those that have already been added.
      * </p>
-     * 
+     *
      * @param v the value to add.
      * @throws IllegalArgumentException if <code>v</code> is not comparable with previous entries
      */
@@ -141,7 +141,7 @@ public class Frequency implements Serializable {
             } else {
                 freqTable.put(obj, Long.valueOf(count.longValue() + 1));
             }
-        } catch (ClassCastException ex) {   
+        } catch (ClassCastException ex) {
             //TreeMap will throw ClassCastException if v is not comparable
             throw MathRuntimeException.createIllegalArgumentException(
                   "instance of class {0} not comparable to existing values",
@@ -151,63 +151,65 @@ public class Frequency implements Serializable {
 
     /**
      * Adds 1 to the frequency count for v.
-     * 
+     *
      * @param v the value to add.
      */
     public void addValue(int v) {
         addValue(Long.valueOf(v));
     }
-    
+
     /**
      * Adds 1 to the frequency count for v.
-     * 
+     *
      * @param v the value to add.
+     * @deprecated to be removed in math 3.0
      */
+    @Deprecated
     public void addValue(Integer v) {
         addValue(Long.valueOf(v.longValue()));
     }
 
     /**
      * Adds 1 to the frequency count for v.
-     * 
+     *
      * @param v the value to add.
      */
     public void addValue(long v) {
         addValue(Long.valueOf(v));
     }
-    
+
     /**
      * Adds 1 to the frequency count for v.
-     * 
+     *
      * @param v the value to add.
      */
     public void addValue(char v) {
         addValue(Character.valueOf(v));
     }
-    
+
     /** Clears the frequency table */
     public void clear() {
         freqTable.clear();
     }
-    
+
     /**
      * Returns an Iterator over the set of values that have been added.
      * <p>
-     * If added values are integral (i.e., integers, longs, Integers, or Longs), 
+     * If added values are integral (i.e., integers, longs, Integers, or Longs),
      * they are converted to Longs when they are added, so the objects returned
      * by the Iterator will in this case be Longs.</p>
-     * 
+     *
      * @return values Iterator
      */
     public Iterator<Comparable<?>> valuesIterator() {
         return freqTable.keySet().iterator();
     }
-    
+
     //-------------------------------------------------------------------------
-    
+
     /**
      * Returns the sum of all frequencies.
-     * 
+     *
      * @return the total frequency count.
      */
     public long getSumFreq() {
@@ -222,7 +224,7 @@ public class Frequency implements Serializable {
     /**
      * Returns the number of values = v.
      * Returns 0 if the value is not comparable.
-     * 
+     *
      * @param v the value to lookup.
      * @return the frequency of v.
      * @deprecated replaced by {@link #getCount(Comparable)} as of 2.0
@@ -235,7 +237,7 @@ public class Frequency implements Serializable {
     /**
      * Returns the number of values = v.
      * Returns 0 if the value is not comparable.
-     * 
+     *
      * @param v the value to lookup.
      * @return the frequency of v.
      */
@@ -244,7 +246,7 @@ public class Frequency implements Serializable {
             return getCount(((Integer) v).longValue());
         }
         long result = 0;
-        try { 
+        try {
             Long count =  freqTable.get(v);
             if (count != null) {
                 result = count.longValue();
@@ -257,34 +259,34 @@ public class Frequency implements Serializable {
 
     /**
      * Returns the number of values = v.
-     * 
+     *
      * @param v the value to lookup.
      * @return the frequency of v.
      */
     public long getCount(int v) {
         return getCount(Long.valueOf(v));
     }
-    
+
     /**
      * Returns the number of values = v.
-     * 
+     *
      * @param v the value to lookup.
      * @return the frequency of v.
      */
     public long getCount(long v) {
         return getCount(Long.valueOf(v));
     }
-    
+
     /**
      * Returns the number of values = v.
-     * 
+     *
      * @param v the value to lookup.
      * @return the frequency of v.
      */
     public long getCount(char v) {
         return getCount(Character.valueOf(v));
     }
-    
+
     //-------------------------------------------------------------
 
     /**
@@ -292,14 +294,14 @@ public class Frequency implements Serializable {
      * (as a proportion between 0 and 1).
      * <p>
      * Returns <code>Double.NaN</code> if no values have been added.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values equal to v
      * @deprecated replaced by {@link #getPct(Comparable)} as of 2.0
      */
     @Deprecated
     public double getPct(Object v) {
-        return getCumPct((Comparable<?>) v);
+        return getPct((Comparable<?>) v);
     }
 
     /**
@@ -307,7 +309,7 @@ public class Frequency implements Serializable {
      * (as a proportion between 0 and 1).
      * <p>
      * Returns <code>Double.NaN</code> if no values have been added.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values equal to v
      */
@@ -316,49 +318,49 @@ public class Frequency implements Serializable {
         if (sumFreq == 0) {
             return Double.NaN;
         }
-        return (double) getCount(v) / (double) sumFreq;        
+        return (double) getCount(v) / (double) sumFreq;
     }
-    
+
     /**
      * Returns the percentage of values that are equal to v
      * (as a proportion between 0 and 1).
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values equal to v
      */
     public double getPct(int v) {
-        return getPct(Long.valueOf(v));       
+        return getPct(Long.valueOf(v));
     }
-    
+
     /**
      * Returns the percentage of values that are equal to v
      * (as a proportion between 0 and 1).
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values equal to v
      */
     public double getPct(long v) {
-        return getPct(Long.valueOf(v));         
+        return getPct(Long.valueOf(v));
     }
-    
+
     /**
      * Returns the percentage of values that are equal to v
      * (as a proportion between 0 and 1).
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values equal to v
      */
     public double getPct(char v) {
-        return getPct(Character.valueOf(v));         
+        return getPct(Character.valueOf(v));
     }
-    
+
     //-----------------------------------------------------------------------------------------
-    
+
     /**
      * Returns the cumulative frequency of values less than or equal to v.
      * <p>
      * Returns 0 if v is not comparable to the values set.</p>
-     * 
+     *
      * @param v the value to lookup.
      * @return the proportion of values equal to v
      * @deprecated replaced by {@link #getCumFreq(Comparable)} as of 2.0
@@ -372,24 +374,24 @@ public class Frequency implements Serializable {
      * Returns the cumulative frequency of values less than or equal to v.
      * <p>
      * Returns 0 if v is not comparable to the values set.</p>
-     * 
+     *
      * @param v the value to lookup.
      * @return the proportion of values equal to v
      */
-    @SuppressWarnings("unchecked")
-        public long getCumFreq(Comparable<?> v) {
+    public long getCumFreq(Comparable<?> v) {
         if (getSumFreq() == 0) {
             return 0;
         }
         if (v instanceof Integer) {
             return getCumFreq(((Integer) v).longValue());
         }
+        @SuppressWarnings("unchecked") // OK, freqTable is Comparable<?>
         Comparator<Comparable<?>> c = (Comparator<Comparable<?>>) freqTable.comparator();
         if (c == null) {
             c = new NaturalComparator();
         }
         long result = 0;
-        
+
         try {
             Long value = freqTable.get(v);
             if (value != null) {
@@ -402,11 +404,11 @@ public class Frequency implements Serializable {
         if (c.compare(v, freqTable.firstKey()) < 0) {
             return 0;  // v is comparable, but less than first value
         }
-        
+
         if (c.compare(v, freqTable.lastKey()) >= 0) {
             return getSumFreq();    // v is comparable, but greater than the last value
         }
-        
+
         Iterator<Comparable<?>> values = valuesIterator();
         while (values.hasNext()) {
             Comparable<?> nextValue = values.next();
@@ -418,45 +420,45 @@ public class Frequency implements Serializable {
         }
         return result;
     }
-    
+
      /**
      * Returns the cumulative frequency of values less than or equal to v.
      * <p>
      * Returns 0 if v is not comparable to the values set.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values equal to v
      */
     public long getCumFreq(int v) {
-        return getCumFreq(Long.valueOf(v));       
+        return getCumFreq(Long.valueOf(v));
     }
-    
+
      /**
      * Returns the cumulative frequency of values less than or equal to v.
      * <p>
      * Returns 0 if v is not comparable to the values set.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values equal to v
      */
     public long getCumFreq(long v) {
-        return getCumFreq(Long.valueOf(v));         
+        return getCumFreq(Long.valueOf(v));
     }
-    
+
     /**
      * Returns the cumulative frequency of values less than or equal to v.
      * <p>
      * Returns 0 if v is not comparable to the values set.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values equal to v
      */
     public long getCumFreq(char v) {
-        return getCumFreq(Character.valueOf(v));         
+        return getCumFreq(Character.valueOf(v));
     }
-    
+
     //----------------------------------------------------------------------------------------------
-    
+
     /**
      * Returns the cumulative percentage of values less than or equal to v
      * (as a proportion between 0 and 1).
@@ -464,7 +466,7 @@ public class Frequency implements Serializable {
      * Returns <code>Double.NaN</code> if no values have been added.
      * Returns 0 if at least one value has been added, but v is not comparable
      * to the values set.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values less than or equal to v
      * @deprecated replaced by {@link #getCumPct(Comparable)} as of 2.0
@@ -472,7 +474,7 @@ public class Frequency implements Serializable {
     @Deprecated
     public double getCumPct(Object v) {
         return getCumPct((Comparable<?>) v);
-        
+
     }
 
     /**
@@ -482,7 +484,7 @@ public class Frequency implements Serializable {
      * Returns <code>Double.NaN</code> if no values have been added.
      * Returns 0 if at least one value has been added, but v is not comparable
      * to the values set.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values less than or equal to v
      */
@@ -491,48 +493,48 @@ public class Frequency implements Serializable {
         if (sumFreq == 0) {
             return Double.NaN;
         }
-        return (double) getCumFreq(v) / (double) sumFreq;        
+        return (double) getCumFreq(v) / (double) sumFreq;
     }
-    
+
     /**
      * Returns the cumulative percentage of values less than or equal to v
      * (as a proportion between 0 and 1).
      * <p>
      * Returns 0 if v is not comparable to the values set.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values less than or equal to v
      */
     public double getCumPct(int v) {
-        return getCumPct(Long.valueOf(v));       
+        return getCumPct(Long.valueOf(v));
     }
-    
+
     /**
      * Returns the cumulative percentage of values less than or equal to v
      * (as a proportion between 0 and 1).
      * <p>
      * Returns 0 if v is not comparable to the values set.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values less than or equal to v
      */
     public double getCumPct(long v) {
-        return getCumPct(Long.valueOf(v));         
+        return getCumPct(Long.valueOf(v));
     }
-    
+
     /**
      * Returns the cumulative percentage of values less than or equal to v
      * (as a proportion between 0 and 1).
      * <p>
      * Returns 0 if v is not comparable to the values set.</p>
-     * 
+     *
      * @param v the value to lookup
      * @return the proportion of values less than or equal to v
      */
     public double getCumPct(char v) {
-        return getCumPct(Character.valueOf(v));         
+        return getCumPct(Character.valueOf(v));
     }
-    
+
     /**
      * A Comparator that compares comparable objects using the
      * natural order.  Copied from Commons Collections ComparableComparator.
@@ -546,18 +548,18 @@ public class Frequency implements Serializable {
          * Compare the two {@link Comparable Comparable} arguments.
          * This method is equivalent to:
          * <pre>(({@link Comparable Comparable})o1).{@link Comparable#compareTo compareTo}(o2)</pre>
-         * 
-         * @param  o1 the first object 
+         *
+         * @param  o1 the first object
          * @param  o2 the second object
          * @return  result of comparison
-         * @throws NullPointerException when <i>o1</i> is <code>null</code>, 
+         * @throws NullPointerException when <i>o1</i> is <code>null</code>,
          *         or when <code>((Comparable)o1).compareTo(o2)</code> does
-         * @throws ClassCastException when <i>o1</i> is not a {@link Comparable Comparable}, 
+         * @throws ClassCastException when <i>o1</i> is not a {@link Comparable Comparable},
          *         or when <code>((Comparable)o1).compareTo(o2)</code> does
          */
-        @SuppressWarnings("unchecked")
+        @SuppressWarnings("unchecked") // cast to (T) may throw ClassCastException, see Javadoc
         public int compare(Comparable<T> o1, Comparable<T> o2) {
-            return (o1.compareTo((T) o2));
+            return o1.compareTo((T) o2);
         }
     }
 
@@ -576,8 +578,6 @@ public class Frequency implements Serializable {
     public boolean equals(Object obj) {
         if (this == obj)
             return true;
-        if (obj == null)
-            return false;
         if (!(obj instanceof Frequency))
             return false;
         Frequency other = (Frequency) obj;
