@@ -20,14 +20,12 @@ package org.apache.commons.math.estimation;
 import java.util.ArrayList;
 import java.util.HashSet;
 
-import junit.framework.Test;
 import junit.framework.TestCase;
-import junit.framework.TestSuite;
 
 /**
  * <p>Some of the unit tests are re-implementations of the MINPACK <a
  * href="http://www.netlib.org/minpack/ex/file17">file17</a> and <a
- * href="http://www.netlib.org/minpack/ex/file22">file22</a> test files. 
+ * href="http://www.netlib.org/minpack/ex/file22">file22</a> test files.
  * The redistribution policy for MINPACK is available <a
  * href="http://www.netlib.org/minpack/disclaimer">here</a>, for
  * convenience, it is reproduced below.</p>
@@ -731,8 +729,4 @@ public class GaussNewtonEstimatorTest
 
   }
 
-  public static Test suite() {
-    return new TestSuite(GaussNewtonEstimatorTest.class);
-  }
-
 }
