@@ -30,7 +30,7 @@ import junit.framework.*;
 /**
  * <p>Some of the unit tests are re-implementations of the MINPACK <a
  * href="http://www.netlib.org/minpack/ex/file17">file17</a> and <a
- * href="http://www.netlib.org/minpack/ex/file22">file22</a> test files. 
+ * href="http://www.netlib.org/minpack/ex/file22">file22</a> test files.
  * The redistribution policy for MINPACK is available <a
  * href="http://www.netlib.org/minpack/disclaimer">here</a>, for
  * convenience, it is reproduced below.</p>
@@ -133,7 +133,7 @@ public class MinpackTest
     minpackTest(new HelicalValleyFunction(new double[] { -100.0, 0.0, 0.0},
                                           991.261822123701), false);
   }
-    
+
   public void testMinpackPowellSingular() {
     minpackTest(new PowellSingularFunction(new double[] { 3.0, -1.0, 0.0, 1.0 },
                                            14.6628782986152), false);
@@ -142,7 +142,7 @@ public class MinpackTest
     minpackTest(new PowellSingularFunction(new double[] { 300.0, -100.0, 0.0, 100.0 },
                                            126887.903284750), false);
   }
-    
+
   public void testMinpackFreudensteinRoth() {
     minpackTest(new FreudensteinRothFunction(new double[] { 0.5, -2.0 },
                                              20.0124960961895, 6.99887517584575,
@@ -163,7 +163,7 @@ public class MinpackTest
                                                -0.89680510749204
                                              }), false);
   }
-    
+
   public void testMinpackBard() {
     minpackTest(new BardFunction(1.0, 6.45613629515967, 0.0906359603390466,
                                  new double[] {
@@ -184,7 +184,7 @@ public class MinpackTest
                                    -164464906.857771
                                  }), false);
   }
-    
+
   public void testMinpackKowalikOsborne() {
     minpackTest(new KowalikOsborneFunction(new double[] { 0.25, 0.39, 0.415, 0.39 },
                                            0.0728915102882945,
@@ -214,7 +214,7 @@ public class MinpackTest
                                              0.134575665392506
                                            }), true);
   }
-    
+
   public void testMinpackMeyer() {
     minpackTest(new MeyerFunction(new double[] { 0.02, 4000.0, 250.0 },
                                   41153.4665543031, 9.37794514651874,
@@ -231,9 +231,9 @@ public class MinpackTest
                                     901.268527953801
                                   }), true);
   }
-    
+
   public void testMinpackWatson() {
-  
+
     minpackTest(new WatsonFunction(6, 0.0,
                                    5.47722557505166, 0.0478295939097601,
                                    new double[] {
@@ -316,12 +316,12 @@ public class MinpackTest
                                    }), false);
 
   }
-    
+
   public void testMinpackBox3Dimensional() {
     minpackTest(new Box3DimensionalFunction(10, new double[] { 0.0, 10.0, 20.0 },
                                             32.1115837449572), false);
   }
-    
+
   public void testMinpackJennrichSampson() {
     minpackTest(new JennrichSampsonFunction(10, new double[] { 0.3, 0.4 },
                                             64.5856498144943, 11.1517793413499,
@@ -353,7 +353,7 @@ public class MinpackTest
                                          -0.403688070279258, 0.236665033746463
                                         }), false);
   }
-    
+
   public void testMinpackChebyquad() {
     minpackTest(new ChebyquadFunction(1, 8, 1.0,
                                       1.88623796907732, 1.88623796907732,
@@ -391,7 +391,7 @@ public class MinpackTest
                                         0.833291216194063,  0.940379732824644
                                       }), false);
   }
-    
+
   public void testMinpackBrownAlmostLinear() {
     minpackTest(new BrownAlmostLinearFunction(10, 0.5,
                                               16.5302162063499, 0.0,
@@ -410,7 +410,7 @@ public class MinpackTest
                                                0.979430303349865, 0.979430303349865,
                                                0.979430303349865, 0.979430303349865,
                                                0.979430303349865, 1.20569696650135
-                                              }), false);  
+                                              }), false);
     minpackTest(new BrownAlmostLinearFunction(10, 50.0,
                                               0.9765625e17, 0.0,
                                               new double[] {
@@ -459,7 +459,7 @@ public class MinpackTest
                                                 0.999999999999121
                                               }), false);
     }
-    
+
   public void testMinpackOsborne1() {
       minpackTest(new Osborne1Function(new double[] { 0.5, 1.5, -1.0, 0.01, 0.02, },
                                        0.937564021037838, 0.00739249260904843,
@@ -469,9 +469,9 @@ public class MinpackTest
                                          0.0221227011813076
                                        }), false);
     }
-    
+
   public void testMinpackOsborne2() {
-      
+
     minpackTest(new Osborne2Function(new double[] {
                                        1.3, 0.65, 0.65, 0.7, 0.6,
                                        3.0, 5.0, 7.0, 2.0, 4.5, 5.5
@@ -505,7 +505,7 @@ public class MinpackTest
   }
 
   private static abstract class MinpackFunction implements EstimationProblem {
- 
+
     protected MinpackFunction(int m,
                               double[] startParams,
                               double   theoreticalStartCost,
@@ -564,7 +564,7 @@ public class MinpackTest
       }
       return true;
     }
- 
+
     public WeightedMeasurement[] getMeasurements() {
       WeightedMeasurement[] measurements = new WeightedMeasurement[m];
       for (int i = 0; i < m; ++i) {
@@ -1043,7 +1043,7 @@ public class MinpackTest
       34780.0, 28610.0, 23650.0, 19630.0,
       16370.0, 13720.0, 11540.0,  9744.0,
        8261.0,  7030.0,  6005.0,  5147.0,
-       4427.0,  3820.0,  3307.0,  2872.0                  
+       4427.0,  3820.0,  3307.0,  2872.0
     };
 
   }
@@ -1534,8 +1534,4 @@ public class MinpackTest
 
   }
 
-  public static Test suite() {
-    return new TestSuite(MinpackTest.class);
-  }
-
 }
