@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -19,9 +19,7 @@ package org.apache.commons.math.linear;
 import java.io.Serializable;
 import java.lang.reflect.Array;
 
-import junit.framework.Test;
 import junit.framework.TestCase;
-import junit.framework.TestSuite;
 
 import org.apache.commons.math.Field;
 import org.apache.commons.math.FieldElement;
@@ -32,11 +30,11 @@ import org.apache.commons.math.fraction.FractionField;
 /**
  * Test cases for the {@link ArrayFieldVector} class.
  *
- * @version $Revision: 783702 $ $Date: 2009-06-11 04:54:02 -0400 (Thu, 11 Jun 2009) $
+ * @version $Revision: 903044 $ $Date: 2010-01-25 21:00:09 -0500 (Mon, 25 Jan 2010) $
  */
 public class ArrayFieldVectorTest extends TestCase {
 
-    // 
+    //
     protected Fraction[][] ma1 = {
             {new Fraction(1), new Fraction(2), new Fraction(3)},
             {new Fraction(4), new Fraction(5), new Fraction(6)},
@@ -58,7 +56,7 @@ public class ArrayFieldVectorTest extends TestCase {
             {new Fraction(7), new Fraction(8), new Fraction(9)}
     };
 
-    // Testclass to test the FieldVector<Fraction> interface 
+    // Testclass to test the FieldVector<Fraction> interface
     // only with enough content to support the test
     public static class FieldVectorTestImpl<T extends FieldElement<T>>
         implements FieldVector<T>, Serializable {
@@ -74,7 +72,7 @@ public class ArrayFieldVectorTest extends TestCase {
          * @param length size of the array to build
          * @return a new array
          */
-        @SuppressWarnings("unchecked")
+        @SuppressWarnings("unchecked") // field is of type T
         private T[] buildArray(final int length) {
             return (T[]) Array.newInstance(field.getZero().getClass(), length);
         }
@@ -254,12 +252,6 @@ public class ArrayFieldVectorTest extends TestCase {
 
     }
 
-    public static Test suite() {
-        TestSuite suite = new TestSuite(ArrayFieldVectorTest.class);
-        suite.setName("ArrayFieldVector<Fraction> Tests");
-        return suite;
-    }
-
     public void testConstructors() {
 
         ArrayFieldVector<Fraction> v0 = new ArrayFieldVector<Fraction>(FractionField.getInstance());
@@ -340,7 +332,7 @@ public class ArrayFieldVectorTest extends TestCase {
         ArrayFieldVector<Fraction> v1 = new ArrayFieldVector<Fraction>(vec1);
         ArrayFieldVector<Fraction> v2 = new ArrayFieldVector<Fraction>(vec2);
         ArrayFieldVector<Fraction> v4 = new ArrayFieldVector<Fraction>(vec4);
-        FieldVectorTestImpl<Fraction> v2_t = new FieldVectorTestImpl<Fraction>(vec2); 
+        FieldVectorTestImpl<Fraction> v2_t = new FieldVectorTestImpl<Fraction>(vec2);
 
         FieldVector<Fraction> v_append_1 = v1.append(v2);
         assertEquals(6, v_append_1.getDimension());
@@ -436,7 +428,7 @@ public class ArrayFieldVectorTest extends TestCase {
         }
 
 
-        ArrayFieldVector<Fraction> vout10 = (ArrayFieldVector<Fraction>) v1.copy();       
+        ArrayFieldVector<Fraction> vout10 = (ArrayFieldVector<Fraction>) v1.copy();
         ArrayFieldVector<Fraction> vout10_2 = (ArrayFieldVector<Fraction>) v1.copy();
         assertEquals(vout10, vout10_2);
         vout10_2.setEntry(0, new Fraction(11, 10));
@@ -444,7 +436,7 @@ public class ArrayFieldVectorTest extends TestCase {
 
     }
 
-    public void testMapFunctions() { 
+    public void testMapFunctions() {
         ArrayFieldVector<Fraction> v1 = new ArrayFieldVector<Fraction>(vec1);
 
         //octave =  v1 .+ 2.0
@@ -504,12 +496,12 @@ public class ArrayFieldVectorTest extends TestCase {
 
     }
 
-    public void testBasicFunctions() { 
+    public void testBasicFunctions() {
         ArrayFieldVector<Fraction> v1 = new ArrayFieldVector<Fraction>(vec1);
         ArrayFieldVector<Fraction> v2 = new ArrayFieldVector<Fraction>(vec2);
         new ArrayFieldVector<Fraction>(vec_null);
 
-        FieldVectorTestImpl<Fraction> v2_t = new FieldVectorTestImpl<Fraction>(vec2); 
+        FieldVectorTestImpl<Fraction> v2_t = new FieldVectorTestImpl<Fraction>(vec2);
 
         //octave =  v1 + v2
         ArrayFieldVector<Fraction> v_add = v1.add(v2);
@@ -570,46 +562,46 @@ public class ArrayFieldVectorTest extends TestCase {
         Fraction[] result_projection_2 = {new Fraction(128, 77), new Fraction(160, 77), new Fraction(192, 77)};
         checkArray("compare vect", v_projection_2.getData(), result_projection_2);
 
-    }  
+    }
 
-    public void testMisc() { 
+    public void testMisc() {
         ArrayFieldVector<Fraction> v1 = new ArrayFieldVector<Fraction>(vec1);
         ArrayFieldVector<Fraction> v4 = new ArrayFieldVector<Fraction>(vec4);
         FieldVector<Fraction> v4_2 = new ArrayFieldVector<Fraction>(vec4);
 
         String out1 = v1.toString();
         assertTrue("some output ",  out1.length()!=0);
-        /*    
+        /*
          Fraction[] dout1 = v1.copyOut();
         assertEquals(3, dout1.length);
-        assertNotSame("testData not same object ", v1.data, dout1);   
-         */      
+        assertNotSame("testData not same object ", v1.data, dout1);
+         */
         try {
-            v1.checkVectorDimensions(2); 
+            v1.checkVectorDimensions(2);
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
         } catch (Exception e) {
             fail("wrong exception caught");
-        } 
+        }
 
        try {
-            v1.checkVectorDimensions(v4); 
+            v1.checkVectorDimensions(v4);
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
         } catch (Exception e) {
             fail("wrong exception caught");
-        }        
+        }
 
         try {
-            v1.checkVectorDimensions(v4_2); 
+            v1.checkVectorDimensions(v4_2);
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
         } catch (Exception e) {
             fail("wrong exception caught");
-        }        
+        }
 
     }
 
@@ -617,7 +609,7 @@ public class ArrayFieldVectorTest extends TestCase {
         ArrayFieldVector<Fraction> v = new ArrayFieldVector<Fraction>(vec1);
         assertEquals(v,TestUtils.serializeAndRecover(v));
     }
-  
+
     /** verifies that two vectors are equals */
     protected void checkArray(String msg, Fraction[] m, Fraction[] n) {
         if (m.length != n.length) {
