@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -17,26 +17,28 @@
 package org.apache.commons.math.linear;
 
 import java.io.Serializable;
+import java.util.Iterator;
 
-import junit.framework.Test;
 import junit.framework.TestCase;
-import junit.framework.TestSuite;
 
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.analysis.UnivariateRealFunction;
 
 /**
  * Test cases for the {@link ArrayRealVector} class.
  *
- * @version $Revision: 783702 $ $Date: 2009-06-11 04:54:02 -0400 (Thu, 11 Jun 2009) $
+ * @version $Revision: 904231 $ $Date: 2010-01-28 14:42:31 -0500 (Thu, 28 Jan 2010) $
  */
 public class ArrayRealVectorTest extends TestCase {
 
-    // 
+    //
     protected double[][] ma1 = {{1d, 2d, 3d}, {4d, 5d, 6d}, {7d, 8d, 9d}};
     protected double[] vec1 = {1d, 2d, 3d};
     protected double[] vec2 = {4d, 5d, 6d};
     protected double[] vec3 = {7d, 8d, 9d};
     protected double[] vec4 = {1d, 2d, 3d, 4d, 5d, 6d, 7d, 8d, 9d};
+    protected double[] vec5 = { -4d, 0d, 3d, 1d, -6d, 3d};
     protected double[] vec_null = {0d, 0d, 0d};
     protected Double[] dvec1 = {1d, 2d, 3d, 4d, 5d, 6d, 7d, 8d, 9d};
     protected double[][] mat1 = {{1d, 2d, 3d}, {4d, 5d, 6d},{ 7d, 8d, 9d}};
@@ -45,7 +47,7 @@ public class ArrayRealVectorTest extends TestCase {
     protected double entryTolerance = 10E-16;
     protected double normTolerance = 10E-14;
 
-    // Testclass to test the RealVector interface 
+    // Testclass to test the RealVector interface
     // only with enough content to support the test
     public static class RealVectorTestImpl implements RealVector, Serializable {
 
@@ -63,6 +65,43 @@ public class ArrayRealVectorTest extends TestCase {
             return new UnsupportedOperationException("Not supported, unneeded for test purposes");
         }
 
+        public RealVector map(UnivariateRealFunction function) throws FunctionEvaluationException {
+            throw unsupported();
+        }
+
+        public RealVector mapToSelf(UnivariateRealFunction function) throws FunctionEvaluationException {
+            throw unsupported();
+        }
+
+        public Iterator<Entry> iterator() {
+            return new Iterator<Entry>() {
+                int i = 0;
+                public boolean hasNext() {
+                    return i<data.length;
+                }
+                public Entry next() {
+                    final int j = i++;
+                    Entry e = new Entry() {
+                        @Override
+                        public double getValue() {
+                            return data[j];
+                        }
+                        @Override
+                        public void setValue(double newValue) {
+                            data[j] = newValue;
+                        }
+                    };
+                    e.setIndex(j);
+                    return e;
+                }
+                public void remove() { }
+            };
+        }
+
+        public Iterator<Entry> sparseIterator() {
+            return iterator();
+        }
+
         public RealVector copy() {
             throw unsupported();
         }
@@ -461,12 +500,6 @@ public class ArrayRealVectorTest extends TestCase {
 
     }
 
-    public static Test suite() {
-        TestSuite suite = new TestSuite(ArrayRealVectorTest.class);
-        suite.setName("ArrayRealVector Tests");
-        return suite;
-    }
-
     public void testConstructors() {
 
         ArrayRealVector v0 = new ArrayRealVector();
@@ -484,6 +517,18 @@ public class ArrayRealVectorTest extends TestCase {
         assertEquals("testData len", 3, v3.getDimension());
         assertEquals("testData is 2.0 ", 2.0, v3.getEntry(1));
 
+        ArrayRealVector v3_bis = new ArrayRealVector(vec1, true);
+        assertEquals("testData len", 3, v3_bis.getDimension());
+        assertEquals("testData is 2.0 ", 2.0, v3_bis.getEntry(1));
+        assertNotSame(v3_bis.getDataRef(), vec1);
+        assertNotSame(v3_bis.getData(), vec1);
+
+        ArrayRealVector v3_ter = new ArrayRealVector(vec1, false);
+        assertEquals("testData len", 3, v3_ter.getDimension());
+        assertEquals("testData is 2.0 ", 2.0, v3_ter.getEntry(1));
+        assertSame(v3_ter.getDataRef(), vec1);
+        assertNotSame(v3_ter.getData(), vec1);
+
         ArrayRealVector v4 = new ArrayRealVector(vec4, 3, 2);
         assertEquals("testData len", 2, v4.getDimension());
         assertEquals("testData is 4.0 ", 4.0, v4.getEntry(0));
@@ -540,14 +585,57 @@ public class ArrayRealVectorTest extends TestCase {
         assertEquals("testData len", 10, v9.getDimension());
         assertEquals("testData is 1.0 ", 1.0, v9.getEntry(7));
 
-    }
+        ArrayRealVector v10 = new ArrayRealVector(v2, new RealVectorTestImpl(vec3));
+        assertEquals("testData len", 8, v10.getDimension());
+        assertEquals("testData is 1.23 ", 1.23, v10.getEntry(4));
+        assertEquals("testData is 7.0 ", 7.0, v10.getEntry(5));
+
+        ArrayRealVector v11 = new ArrayRealVector(new RealVectorTestImpl(vec3), v2);
+        assertEquals("testData len", 8, v11.getDimension());
+        assertEquals("testData is 9.0 ", 9.0, v11.getEntry(2));
+        assertEquals("testData is 1.23 ", 1.23, v11.getEntry(3));
+
+        ArrayRealVector v12 = new ArrayRealVector(v2, vec3);
+        assertEquals("testData len", 8, v12.getDimension());
+        assertEquals("testData is 1.23 ", 1.23, v12.getEntry(4));
+        assertEquals("testData is 7.0 ", 7.0, v12.getEntry(5));
+
+        ArrayRealVector v13 = new ArrayRealVector(vec3, v2);
+        assertEquals("testData len", 8, v13.getDimension());
+        assertEquals("testData is 9.0 ", 9.0, v13.getEntry(2));
+        assertEquals("testData is 1.23 ", 1.23, v13.getEntry(3));
+
+        ArrayRealVector v14 = new ArrayRealVector(vec3, vec4);
+        assertEquals("testData len", 12, v14.getDimension());
+        assertEquals("testData is 9.0 ", 9.0, v14.getEntry(2));
+        assertEquals("testData is 1.0 ", 1.0, v14.getEntry(3));
+
+        try {
+            new ArrayRealVector((double[]) null, false);
+            fail("expected exception");
+        } catch (NullPointerException npe) {
+            // expected
+        } catch (Exception e) {
+            fail("wrong exception caught");
+        }
+
+        try {
+            new ArrayRealVector(new double[0], false);
+            fail("expected exception");
+        } catch (IllegalArgumentException iae) {
+            // expected
+        } catch (Exception e) {
+            fail("wrong exception caught");
+        }
+
+   }
 
     public void testDataInOut() {
 
         ArrayRealVector v1 = new ArrayRealVector(vec1);
         ArrayRealVector v2 = new ArrayRealVector(vec2);
         ArrayRealVector v4 = new ArrayRealVector(vec4);
-        RealVectorTestImpl v2_t = new RealVectorTestImpl(vec2); 
+        RealVectorTestImpl v2_t = new RealVectorTestImpl(vec2);
 
         RealVector v_append_1 = v1.append(v2);
         assertEquals("testData len", 6, v_append_1.getDimension());
@@ -565,6 +653,10 @@ public class ArrayRealVectorTest extends TestCase {
         assertEquals("testData len", 6, v_append_4.getDimension());
         assertEquals("testData is 4.0 ", 4.0, v_append_4.getEntry(3));
 
+        RealVector v_append_5 = v1.append((RealVector) v2);
+        assertEquals("testData len", 6, v_append_5.getDimension());
+        assertEquals("testData is 4.0 ", 4.0, v_append_5.getEntry(3));
+
         RealVector v_copy = v1.copy();
         assertEquals("testData len", 3, v_copy.getDimension());
         assertNotSame("testData not same object ", v1.data, v_copy.getData());
@@ -643,7 +735,7 @@ public class ArrayRealVectorTest extends TestCase {
         }
 
 
-        ArrayRealVector vout10 = (ArrayRealVector) v1.copy();       
+        ArrayRealVector vout10 = (ArrayRealVector) v1.copy();
         ArrayRealVector vout10_2 = (ArrayRealVector) v1.copy();
         assertEquals(vout10, vout10_2);
         vout10_2.setEntry(0, 1.1);
@@ -651,7 +743,7 @@ public class ArrayRealVectorTest extends TestCase {
 
     }
 
-    public void testMapFunctions() { 
+    public void testMapFunctions() {
         ArrayRealVector v1 = new ArrayRealVector(vec1);
 
         //octave =  v1 .+ 2.0
@@ -852,7 +944,7 @@ public class ArrayRealVectorTest extends TestCase {
 
         //octave =  asin(vat)
         RealVector v_mapAsinToSelf = vat.copy();
-        v_mapAsinToSelf.mapAsinToSelf();        
+        v_mapAsinToSelf.mapAsinToSelf();
         double[] result_mapAsinToSelf = {0.0d,5.235987755982989e-01d,1.570796326794897e+00d};
         assertClose("compare vectors" ,result_mapAsinToSelf,v_mapAsinToSelf.getData(),normTolerance);
 
@@ -979,22 +1071,26 @@ public class ArrayRealVectorTest extends TestCase {
 
     }
 
-    public void testBasicFunctions() { 
+    public void testBasicFunctions() {
         ArrayRealVector v1 = new ArrayRealVector(vec1);
         ArrayRealVector v2 = new ArrayRealVector(vec2);
+        ArrayRealVector v5 = new ArrayRealVector(vec5);
         ArrayRealVector v_null = new ArrayRealVector(vec_null);
 
-        RealVectorTestImpl v2_t = new RealVectorTestImpl(vec2); 
+        RealVectorTestImpl v2_t = new RealVectorTestImpl(vec2);
 
-        //octave =  sqrt(sumsq(v1))
-        double d_getNorm = v1.getNorm();
-        assertEquals("compare values  ", 3.7416573867739413,d_getNorm);
+        // emacs calc: [-4, 0, 3, 1, -6, 3] A --> 8.4261497731763586307
+        double d_getNorm = v5.getNorm();
+        assertEquals("compare values  ", 8.4261497731763586307, d_getNorm);
 
-        double d_getL1Norm = v1.getL1Norm();
-        assertEquals("compare values  ",6.0, d_getL1Norm);
+        // emacs calc: [-4, 0, 3, 1, -6, 3] vN --> 17
+        double d_getL1Norm = v5.getL1Norm();
+        assertEquals("compare values  ", 17.0, d_getL1Norm);
+
+        // emacs calc: [-4, 0, 3, 1, -6, 3] vn --> 6
+        double d_getLInfNorm = v5.getLInfNorm();
+        assertEquals("compare values  ", 6.0, d_getLInfNorm);
 
-        double d_getLInfNorm = v1.getLInfNorm();
-        assertEquals("compare values  ",6.0, d_getLInfNorm);
 
         //octave =  sqrt(sumsq(v1-v2))
         double dist = v1.getDistance(v2);
@@ -1004,6 +1100,10 @@ public class ArrayRealVectorTest extends TestCase {
         double dist_2 = v1.getDistance(v2_t);
         assertEquals("compare values  ", v1.subtract(v2).getNorm(),dist_2 );
 
+        //octave =  sqrt(sumsq(v1-v2))
+        double dist_3 = v1.getDistance((RealVector) v2);
+        assertEquals("compare values  ", v1.subtract(v2).getNorm(),dist_3 );
+
         //octave =  ???
         double d_getL1Distance = v1. getL1Distance(v2);
         assertEquals("compare values  ",9d, d_getL1Distance );
@@ -1011,6 +1111,9 @@ public class ArrayRealVectorTest extends TestCase {
         double d_getL1Distance_2 = v1. getL1Distance(v2_t);
         assertEquals("compare values  ",9d, d_getL1Distance_2 );
 
+        double d_getL1Distance_3 = v1. getL1Distance((RealVector) v2);
+        assertEquals("compare values  ",9d, d_getL1Distance_3 );
+
         //octave =  ???
         double d_getLInfDistance = v1. getLInfDistance(v2);
         assertEquals("compare values  ",3d, d_getLInfDistance );
@@ -1018,6 +1121,9 @@ public class ArrayRealVectorTest extends TestCase {
         double d_getLInfDistance_2 = v1. getLInfDistance(v2_t);
         assertEquals("compare values  ",3d, d_getLInfDistance_2 );
 
+        double d_getLInfDistance_3 = v1. getLInfDistance((RealVector) v2);
+        assertEquals("compare values  ",3d, d_getLInfDistance_3 );
+
         //octave =  v1 + v2
         ArrayRealVector v_add = v1.add(v2);
         double[] result_add = {5d, 7d, 9d};
@@ -1046,6 +1152,10 @@ public class ArrayRealVectorTest extends TestCase {
         double[] result_ebeMultiply_2 = {4d, 10d, 18d};
         assertClose("compare vect" ,v_ebeMultiply_2.getData(),result_ebeMultiply_2,normTolerance);
 
+        RealVector  v_ebeMultiply_3 = v1.ebeMultiply((RealVector) v2);
+        double[] result_ebeMultiply_3 = {4d, 10d, 18d};
+        assertClose("compare vect" ,v_ebeMultiply_3.getData(),result_ebeMultiply_3,normTolerance);
+
         // octave v1 ./ v2
         ArrayRealVector  v_ebeDivide = v1.ebeDivide(v2);
         double[] result_ebeDivide = {0.25d, 0.4d, 0.5d};
@@ -1055,6 +1165,10 @@ public class ArrayRealVectorTest extends TestCase {
         double[] result_ebeDivide_2 = {0.25d, 0.4d, 0.5d};
         assertClose("compare vect" ,v_ebeDivide_2.getData(),result_ebeDivide_2,normTolerance);
 
+        RealVector  v_ebeDivide_3 = v1.ebeDivide((RealVector) v2);
+        double[] result_ebeDivide_3 = {0.25d, 0.4d, 0.5d};
+        assertClose("compare vect" ,v_ebeDivide_3.getData(),result_ebeDivide_3,normTolerance);
+
         // octave  dot(v1,v2)
         double dot =  v1.dotProduct(v2);
         assertEquals("compare val ",32d, dot);
@@ -1069,8 +1183,11 @@ public class ArrayRealVectorTest extends TestCase {
         RealMatrix m_outerProduct_2 = v1.outerProduct(v2_t);
         assertEquals("compare val ",4d, m_outerProduct_2.getEntry(0,0));
 
+        RealMatrix m_outerProduct_3 = v1.outerProduct((RealVector) v2);
+        assertEquals("compare val ",4d, m_outerProduct_3.getEntry(0,0));
+
         RealVector v_unitVector = v1.unitVector();
-        RealVector v_unitVector_2 = v1.mapDivide(v1.getNorm()); 
+        RealVector v_unitVector_2 = v1.mapDivide(v1.getNorm());
         assertClose("compare vect" ,v_unitVector.getData(),v_unitVector_2.getData(),normTolerance);
 
         try {
@@ -1102,46 +1219,50 @@ public class ArrayRealVectorTest extends TestCase {
         double[] result_projection_2 = {1.662337662337662, 2.0779220779220777, 2.493506493506493};
         assertClose("compare vect", v_projection_2.getData(), result_projection_2, normTolerance);
 
-    }  
+        RealVector v_projection_3 = v1.projection(v2.getData());
+        double[] result_projection_3 = {1.662337662337662, 2.0779220779220777, 2.493506493506493};
+        assertClose("compare vect", v_projection_3.getData(), result_projection_3, normTolerance);
 
-    public void testMisc() { 
+    }
+
+    public void testMisc() {
         ArrayRealVector v1 = new ArrayRealVector(vec1);
         ArrayRealVector v4 = new ArrayRealVector(vec4);
         RealVector v4_2 = new ArrayRealVector(vec4);
 
         String out1 = v1.toString();
         assertTrue("some output ",  out1.length()!=0);
-        /*    
+        /*
          double[] dout1 = v1.copyOut();
         assertEquals("testData len", 3, dout1.length);
-        assertNotSame("testData not same object ", v1.data, dout1);   
-         */      
+        assertNotSame("testData not same object ", v1.data, dout1);
+         */
         try {
-            v1.checkVectorDimensions(2); 
+            v1.checkVectorDimensions(2);
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
         } catch (Exception e) {
             fail("wrong exception caught");
-        } 
+        }
 
        try {
-            v1.checkVectorDimensions(v4); 
+            v1.checkVectorDimensions(v4);
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
         } catch (Exception e) {
             fail("wrong exception caught");
-        }        
+        }
 
         try {
-            v1.checkVectorDimensions(v4_2); 
+            v1.checkVectorDimensions(v4_2);
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
         } catch (Exception e) {
             fail("wrong exception caught");
-        }        
+        }
 
     }
 
@@ -1158,6 +1279,8 @@ public class ArrayRealVectorTest extends TestCase {
         assertFalse(v.isInfinite());
         v.setEntry(1, 1);
         assertTrue(v.isInfinite());
+        v.setEntry(0, 1);
+        assertFalse(v.isInfinite());
 
         v.setEntry(0, 0);
         assertEquals(v, new ArrayRealVector(new double[] { 0, 1, 2 }));
@@ -1170,14 +1293,45 @@ public class ArrayRealVectorTest extends TestCase {
         assertTrue(new ArrayRealVector(new double[] { Double.NaN, 1, 2 }).hashCode() !=
                    new ArrayRealVector(new double[] { 0, 1, 2 }).hashCode());
 
+        assertTrue(v.equals(v));
+        assertTrue(v.equals(v.copy()));
+        assertFalse(v.equals(null));
+        assertFalse(v.equals(v.getDataRef()));
+        assertFalse(v.equals(v.getSubVector(0, v.getDimension() - 1)));
+        assertTrue(v.equals(v.getSubVector(0, v.getDimension())));
+
     }
 
     public void testSerial()  {
         ArrayRealVector v = new ArrayRealVector(new double[] { 0, 1, 2 });
         assertEquals(v,TestUtils.serializeAndRecover(v));
     }
-    
-    
+
+
+    public void testMinMax()  {
+        ArrayRealVector v1 = new ArrayRealVector(new double[] { 0, -6, 4, 12, 7 });
+        assertEquals(1,  v1.getMinIndex());
+        assertEquals(-6, v1.getMinValue(), 1.0e-12);
+        assertEquals(3,  v1.getMaxIndex());
+        assertEquals(12, v1.getMaxValue(), 1.0e-12);
+        ArrayRealVector v2 = new ArrayRealVector(new double[] { Double.NaN, 3, Double.NaN, -2 });
+        assertEquals(3,  v2.getMinIndex());
+        assertEquals(-2, v2.getMinValue(), 1.0e-12);
+        assertEquals(1,  v2.getMaxIndex());
+        assertEquals(3, v2.getMaxValue(), 1.0e-12);
+        ArrayRealVector v3 = new ArrayRealVector(new double[] { Double.NaN, Double.NaN });
+        assertEquals(-1,  v3.getMinIndex());
+        assertTrue(Double.isNaN(v3.getMinValue()));
+        assertEquals(-1,  v3.getMaxIndex());
+        assertTrue(Double.isNaN(v3.getMaxValue()));
+        ArrayRealVector v4 = new ArrayRealVector(new double[0]);
+        assertEquals(-1,  v4.getMinIndex());
+        assertTrue(Double.isNaN(v4.getMinValue()));
+        assertEquals(-1,  v4.getMaxIndex());
+        assertTrue(Double.isNaN(v4.getMaxValue()));
+    }
+
+
     /** verifies that two vectors are close (sup norm) */
     protected void assertClose(String msg, double[] m, double[] n,
             double tolerance) {
