@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,62 +16,60 @@
  */
 package org.apache.commons.math.linear;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import java.math.BigDecimal;
 
+import junit.framework.TestCase;
+
 
 /**
  * Test cases for the {@link BigMatrixImpl} class.
  *
- * @version $Revision: 790372 $ $Date: 2009-07-01 16:48:19 -0400 (Wed, 01 Jul 2009) $
+ * @version $Revision: 902201 $ $Date: 2010-01-22 13:18:16 -0500 (Fri, 22 Jan 2010) $
  */
 @Deprecated
 public final class BigMatrixImplTest extends TestCase {
-    
+
     // Test data for String constructors
     protected  String[][] testDataString = { {"1","2","3"}, {"2","5","3"}, {"1","0","8"} };
-    
+
     // 3 x 3 identity matrix
     protected double[][] id = { {1d,0d,0d}, {0d,1d,0d}, {0d,0d,1d} };
-    
+
     // Test data for group operations
     protected double[][] testData = { {1d,2d,3d}, {2d,5d,3d}, {1d,0d,8d} };
     protected double[][] testDataLU = {{2d, 5d, 3d}, {.5d, -2.5d, 6.5d}, {0.5d, 0.2d, .2d}};
     protected double[][] testDataPlus2 = { {3d,4d,5d}, {4d,7d,5d}, {3d,2d,10d} };
-    protected double[][] testDataMinus = { {-1d,-2d,-3d}, {-2d,-5d,-3d}, 
+    protected double[][] testDataMinus = { {-1d,-2d,-3d}, {-2d,-5d,-3d},
             {-1d,0d,-8d} };
     protected double[] testDataRow1 = {1d,2d,3d};
     protected double[] testDataCol3 = {3d,3d,8d};
-    protected double[][] testDataInv = 
+    protected double[][] testDataInv =
         { {-40d,16d,9d}, {13d,-5d,-3d}, {5d,-2d,-1d} };
     protected double[] preMultTest = {8,12,33};
     protected double[][] testData2 ={ {1d,2d,3d}, {2d,5d,3d}};
     protected double[][] testData2T = { {1d,2d}, {2d,5d}, {3d,3d}};
-    protected double[][] testDataPlusInv = 
+    protected double[][] testDataPlusInv =
         { {-39d,18d,12d}, {15d,0d,0d}, {6d,-2d,7d} };
-    
+
     // lu decomposition tests
     protected double[][] luData = { {2d,3d,3d}, {0d,5d,7d}, {6d,9d,8d} };
     protected double[][] luDataLUDecomposition = { {6d,9d,8d}, {0d,5d,7d},
             {0.33333333333333,0d,0.33333333333333} };
-    
+
     // singular matrices
     protected double[][] singular = { {2d,3d}, {2d,3d} };
     protected double[][] bigSingular = {{1d,2d,3d,4d}, {2d,5d,3d,4d},
             {7d,3d,256d,1930d}, {3d,7d,6d,8d}}; // 4th row = 1st + 2nd
     protected double[][] detData = { {1d,2d,3d}, {4d,5d,6d}, {7d,8d,10d} };
     protected double[][] detData2 = { {1d, 3d}, {2d, 4d}};
-    
+
     // vectors
     protected double[] testVector = {1,2,3};
     protected double[] testVector2 = {1,2,3,4};
-    
+
     // submatrix accessor tests
     protected double[][] subTestData = {{1, 2, 3, 4}, {1.5, 2.5, 3.5, 4.5},
-            {2, 4, 6, 8}, {4, 5, 6, 7}}; 
+            {2, 4, 6, 8}, {4, 5, 6, 7}};
     // array selections
     protected double[][] subRows02Cols13 = { {2, 4}, {4, 8}};
     protected double[][] subRows03Cols12 = { {2, 3}, {5, 6}};
@@ -89,20 +87,14 @@ public final class BigMatrixImplTest extends TestCase {
     // column matrices
     protected double[][] subColumn1 = {{2}, {2.5}, {4}, {5}};
     protected double[][] subColumn3 = {{4}, {4.5}, {8}, {7}};
-    
+
     // tolerances
     protected double entryTolerance = 10E-16;
     protected double normTolerance = 10E-14;
-    
+
     public BigMatrixImplTest(String name) {
         super(name);
     }
-    
-    public static Test suite() {
-        TestSuite suite = new TestSuite(BigMatrixImplTest.class);
-        suite.setName("BigMatrixImpl Tests");
-        return suite;
-    }
 
     public static final double[] asDouble(BigDecimal[] data) {
         double d[] = new double[data.length];
@@ -149,8 +141,8 @@ public final class BigMatrixImplTest extends TestCase {
         assertEquals("testData2 row dimension",m2.getRowDimension(),2);
         assertEquals("testData2 column dimension",m2.getColumnDimension(),3);
         assertTrue("testData2 is not square",!m2.isSquare());
-    }  
-    
+    }
+
     /** test copy functions */
     public void testCopyFunctions() {
         BigMatrixImpl m1 = new BigMatrixImpl(testData);
@@ -160,7 +152,7 @@ public final class BigMatrixImplTest extends TestCase {
         BigMatrixImpl m4 = new BigMatrixImpl(m3.getData(), false);
         assertEquals(m4,m3);
     }
-    
+
     /** test constructors */
     public void testConstructors() {
         BigMatrix m1 = new BigMatrixImpl(testData);
@@ -211,7 +203,7 @@ public final class BigMatrixImplTest extends TestCase {
             // expected
         }
     }
-    
+
     /** test add */
     public void testAdd() {
         BigMatrixImpl m = new BigMatrixImpl(testData);
@@ -224,9 +216,9 @@ public final class BigMatrixImplTest extends TestCase {
                     testDataPlusInv[row][col],sumEntries[row][col],
                         entryTolerance);
             }
-        }    
+        }
     }
-    
+
     /** test add failure */
     public void testAddFail() {
         BigMatrixImpl m = new BigMatrixImpl(testData);
@@ -238,7 +230,7 @@ public final class BigMatrixImplTest extends TestCase {
             // ignored
         }
     }
-    
+
     /** test norm */
     public void testNorm() {
         BigMatrixImpl m = new BigMatrixImpl(testData);
@@ -246,7 +238,7 @@ public final class BigMatrixImplTest extends TestCase {
         assertEquals("testData norm",14d,m.getNorm().doubleValue(),entryTolerance);
         assertEquals("testData2 norm",7d,m2.getNorm().doubleValue(),entryTolerance);
     }
-    
+
      /** test m-n = m + -n */
     public void testPlusMinus() {
         BigMatrixImpl m = new BigMatrixImpl(testData);
@@ -258,9 +250,9 @@ public final class BigMatrixImplTest extends TestCase {
             fail("Expecting illegalArgumentException");
         } catch (IllegalArgumentException ex) {
             // ignored
-        }      
+        }
     }
-   
+
     /** test multiply */
      public void testMultiply() {
         BigMatrixImpl m = new BigMatrixImpl(testData);
@@ -276,28 +268,28 @@ public final class BigMatrixImplTest extends TestCase {
         assertClose("identity multiply",identity.multiply(mInv),
             mInv,entryTolerance);
         assertClose("identity multiply",m2.multiply(identity),
-            m2,entryTolerance); 
+            m2,entryTolerance);
         try {
             m.multiply(new BigMatrixImpl(bigSingular));
             fail("Expecting illegalArgumentException");
         } catch (IllegalArgumentException ex) {
             // ignored
-        }      
-    }   
-    
+        }
+    }
+
     //Additional Test for BigMatrixImplTest.testMultiply
 
     private double[][] d3 = new double[][] {{1,2,3,4},{5,6,7,8}};
     private double[][] d4 = new double[][] {{1},{2},{3},{4}};
     private double[][] d5 = new double[][] {{30},{70}};
-     
-    public void testMultiply2() { 
+
+    public void testMultiply2() {
        BigMatrix m3 = new BigMatrixImpl(d3);
        BigMatrix m4 = new BigMatrixImpl(d4);
        BigMatrix m5 = new BigMatrixImpl(d5);
        assertClose("m3*m4=m5", m3.multiply(m4), m5, entryTolerance);
-   }  
-        
+   }
+
     /** test isSingular */
     public void testIsSingular() {
         BigMatrixImpl m = new BigMatrixImpl(singular);
@@ -309,14 +301,14 @@ public final class BigMatrixImplTest extends TestCase {
         m = new BigMatrixImpl(testData);
         assertTrue("testData nonsingular",!m.isSingular());
     }
-        
+
     /** test inverse */
     public void testInverse() {
         BigMatrixImpl m = new BigMatrixImpl(testData);
         BigMatrix mInv = new BigMatrixImpl(testDataInv);
         assertClose("inverse",mInv,m.inverse(),normTolerance);
         assertClose("inverse^2",m,m.inverse().inverse(),10E-12);
-        
+
         // Not square
         m = new BigMatrixImpl(testData2);
         try {
@@ -325,7 +317,7 @@ public final class BigMatrixImplTest extends TestCase {
         } catch (InvalidMatrixException ex) {
             // expected
         }
-        
+
         // Singular
         m = new BigMatrixImpl(singular);
         try {
@@ -335,7 +327,7 @@ public final class BigMatrixImplTest extends TestCase {
             // expected
         }
     }
-    
+
     /** test solve */
     public void testSolve() {
         BigMatrixImpl m = new BigMatrixImpl(testData);
@@ -350,7 +342,7 @@ public final class BigMatrixImplTest extends TestCase {
             fail("expecting IllegalArgumentException");
         } catch (IllegalArgumentException ex) {
             // ignored
-        }       
+        }
         BigMatrix bs = new BigMatrixImpl(bigSingular);
         try {
             bs.solve(bs);
@@ -369,22 +361,22 @@ public final class BigMatrixImplTest extends TestCase {
             fail("Expecting illegalArgumentException");
         } catch (IllegalArgumentException ex) {
             // ignored
-        } 
+        }
         try {
             (new BigMatrixImpl(testData2)).luDecompose();
             fail("Expecting InvalidMatrixException");
         } catch (InvalidMatrixException ex) {
             // ignored
-        }  
+        }
     }
-    
+
     /** test determinant */
-    public void testDeterminant() {       
+    public void testDeterminant() {
         BigMatrix m = new BigMatrixImpl(bigSingular);
         assertEquals("singular determinant",0,m.getDeterminant().doubleValue(),0);
         m = new BigMatrixImpl(detData);
         assertEquals("nonsingular test",-3d,m.getDeterminant().doubleValue(),normTolerance);
-        
+
         // Examples verified against R (version 1.8.1, Red Hat Linux 9)
         m = new BigMatrixImpl(detData2);
         assertEquals("nonsingular R test 1",-2d,m.getDeterminant().doubleValue(),normTolerance);
@@ -396,9 +388,9 @@ public final class BigMatrixImplTest extends TestCase {
             fail("Expecting InvalidMatrixException, got " + d);
         } catch (InvalidMatrixException ex) {
             // ignored
-        }      
+        }
     }
-    
+
     /** test trace */
     public void testTrace() {
         BigMatrix m = new BigMatrixImpl(id);
@@ -409,16 +401,16 @@ public final class BigMatrixImplTest extends TestCase {
             fail("Expecting NonSquareMatrixException, got " + t);
         } catch (NonSquareMatrixException ex) {
             // ignored
-        }      
+        }
     }
-    
+
     /** test sclarAdd */
     public void testScalarAdd() {
         BigMatrix m = new BigMatrixImpl(testData);
         assertClose("scalar add",new BigMatrixImpl(testDataPlus2),
             m.scalarAdd(new BigDecimal(2d)),entryTolerance);
     }
-                    
+
     /** test operate */
     public void testOperate() {
         BigMatrix m = new BigMatrixImpl(id);
@@ -430,7 +422,7 @@ public final class BigMatrixImplTest extends TestCase {
             fail("Expecting illegalArgumentException");
         } catch (IllegalArgumentException ex) {
             // ignored
-        }      
+        }
     }
 
     /** test issue MATH-209 */
@@ -446,7 +438,7 @@ public final class BigMatrixImplTest extends TestCase {
         assertEquals( 7.0, b[1].doubleValue(), 1.0e-12);
         assertEquals(11.0, b[2].doubleValue(), 1.0e-12);
     }
-    
+
     /** test transpose */
     public void testTranspose() {
         BigMatrix m = new BigMatrixImpl(testData);
@@ -456,7 +448,7 @@ public final class BigMatrixImplTest extends TestCase {
         BigMatrix mt = new BigMatrixImpl(testData2T);
         assertClose("transpose",mt,m.transpose(),normTolerance);
     }
-    
+
     /** test preMultiply by vector */
     public void testPremultiplyVector() {
         BigMatrix m = new BigMatrixImpl(testData);
@@ -469,13 +461,13 @@ public final class BigMatrixImplTest extends TestCase {
             // ignored
         }
     }
-    
+
     public void testPremultiply() {
         BigMatrix m3 = new BigMatrixImpl(d3);
         BigMatrix m4 = new BigMatrixImpl(d4);
         BigMatrix m5 = new BigMatrixImpl(d5);
         assertClose("m3*m4=m5", m4.preMultiply(m3), m5, entryTolerance);
-        
+
         BigMatrixImpl m = new BigMatrixImpl(testData);
         BigMatrixImpl mInv = new BigMatrixImpl(testDataInv);
         BigMatrixImpl identity = new BigMatrixImpl(id);
@@ -493,9 +485,9 @@ public final class BigMatrixImplTest extends TestCase {
             fail("Expecting illegalArgumentException");
         } catch (IllegalArgumentException ex) {
             // ignored
-        }      
+        }
     }
-    
+
     public void testGetVectors() {
         BigMatrix m = new BigMatrixImpl(testData);
         assertClose("get row",m.getRowAsDoubleArray(0),testDataRow1,entryTolerance);
@@ -513,7 +505,7 @@ public final class BigMatrixImplTest extends TestCase {
             // ignored
         }
     }
-      
+
     public void testLUDecomposition() throws Exception {
         BigMatrixImpl m = new BigMatrixImpl(testData);
         BigMatrix lu = m.getLUMatrix();
@@ -544,7 +536,7 @@ public final class BigMatrixImplTest extends TestCase {
             // expected
         }
     }
-    
+
    /**
     * test submatrix accessors
     */
@@ -558,25 +550,25 @@ public final class BigMatrixImplTest extends TestCase {
         BigMatrix mRows03Cols123 = new BigMatrixImpl(subRows03Cols123);
         BigMatrix mRows20Cols123 = new BigMatrixImpl(subRows20Cols123);
         BigMatrix mRows31Cols31 = new BigMatrixImpl(subRows31Cols31);
-        assertEquals("Rows23Cols00", mRows23Cols00, 
+        assertEquals("Rows23Cols00", mRows23Cols00,
                 m.getSubMatrix(2 , 3 , 0, 0));
-        assertEquals("Rows00Cols33", mRows00Cols33, 
+        assertEquals("Rows00Cols33", mRows00Cols33,
                 m.getSubMatrix(0 , 0 , 3, 3));
         assertEquals("Rows01Cols23", mRows01Cols23,
-                m.getSubMatrix(0 , 1 , 2, 3));   
+                m.getSubMatrix(0 , 1 , 2, 3));
         assertEquals("Rows02Cols13", mRows02Cols13,
-                m.getSubMatrix(new int[] {0,2}, new int[] {1,3}));  
+                m.getSubMatrix(new int[] {0,2}, new int[] {1,3}));
         assertEquals("Rows03Cols12", mRows03Cols12,
-                m.getSubMatrix(new int[] {0,3}, new int[] {1,2}));  
+                m.getSubMatrix(new int[] {0,3}, new int[] {1,2}));
         assertEquals("Rows03Cols123", mRows03Cols123,
-                m.getSubMatrix(new int[] {0,3}, new int[] {1,2,3})); 
+                m.getSubMatrix(new int[] {0,3}, new int[] {1,2,3}));
         assertEquals("Rows20Cols123", mRows20Cols123,
-                m.getSubMatrix(new int[] {2,0}, new int[] {1,2,3})); 
+                m.getSubMatrix(new int[] {2,0}, new int[] {1,2,3}));
         assertEquals("Rows31Cols31", mRows31Cols31,
-                m.getSubMatrix(new int[] {3,1}, new int[] {3,1})); 
+                m.getSubMatrix(new int[] {3,1}, new int[] {3,1}));
         assertEquals("Rows31Cols31", mRows31Cols31,
-                m.getSubMatrix(new int[] {3,1}, new int[] {3,1})); 
-        
+                m.getSubMatrix(new int[] {3,1}, new int[] {3,1}));
+
         try {
             m.getSubMatrix(1,0,2,4);
             fail("Expecting MatrixIndexException");
@@ -614,14 +606,14 @@ public final class BigMatrixImplTest extends TestCase {
             // expected
         }
     }
-    
+
     public void testGetColumnMatrix() {
         BigMatrix m = new BigMatrixImpl(subTestData);
         BigMatrix mColumn1 = new BigMatrixImpl(subColumn1);
         BigMatrix mColumn3 = new BigMatrixImpl(subColumn3);
-        assertEquals("Column1", mColumn1, 
+        assertEquals("Column1", mColumn1,
                 m.getColumnMatrix(1));
-        assertEquals("Column3", mColumn3, 
+        assertEquals("Column3", mColumn3,
                 m.getColumnMatrix(3));
         try {
             m.getColumnMatrix(-1);
@@ -636,14 +628,14 @@ public final class BigMatrixImplTest extends TestCase {
             // expected
         }
     }
-    
+
     public void testGetRowMatrix() {
         BigMatrix m = new BigMatrixImpl(subTestData);
         BigMatrix mRow0 = new BigMatrixImpl(subRow0);
         BigMatrix mRow3 = new BigMatrixImpl(subRow3);
-        assertEquals("Row0", mRow0, 
+        assertEquals("Row0", mRow0,
                 m.getRowMatrix(0));
-        assertEquals("Row3", mRow3, 
+        assertEquals("Row3", mRow3,
                 m.getRowMatrix(3));
         try {
             m.getRowMatrix(-1);
@@ -658,7 +650,7 @@ public final class BigMatrixImplTest extends TestCase {
             // expected
         }
     }
-    
+
     public void testEqualsAndHashCode() {
         BigMatrixImpl m = new BigMatrixImpl(testData);
         BigMatrixImpl m1 = (BigMatrixImpl) m.copy();
@@ -676,7 +668,7 @@ public final class BigMatrixImplTest extends TestCase {
         assertTrue(m.hashCode() != m1.hashCode());
         assertFalse(m.equals(m1));
     }
-    
+
     public void testToString() {
         BigMatrixImpl m = new BigMatrixImpl(testData);
         assertEquals("BigMatrixImpl{{1,2,3},{2,5,3},{1,0,8}}",
@@ -685,28 +677,28 @@ public final class BigMatrixImplTest extends TestCase {
         assertEquals("BigMatrixImpl{}",
                 m.toString());
     }
-    
+
     public void testSetSubMatrix() throws Exception {
-        BigDecimal[][] detData3 = 
+        BigDecimal[][] detData3 =
             MatrixUtils.createBigMatrix(detData2).getData();
         BigMatrixImpl m = new BigMatrixImpl(testData);
         m.setSubMatrix(detData3,1,1);
         BigMatrix expected = MatrixUtils.createBigMatrix
             (new double[][] {{1.0,2.0,3.0},{2.0,1.0,3.0},{1.0,2.0,4.0}});
-        assertEquals(expected, m);  
-        
+        assertEquals(expected, m);
+
         m.setSubMatrix(detData3,0,0);
         expected = MatrixUtils.createBigMatrix
             (new double[][] {{1.0,3.0,3.0},{2.0,4.0,3.0},{1.0,2.0,4.0}});
-        assertEquals(expected, m);  
-        
-        BigDecimal[][] testDataPlus3 = 
+        assertEquals(expected, m);
+
+        BigDecimal[][] testDataPlus3 =
             MatrixUtils.createBigMatrix(testDataPlus2).getData();
-        m.setSubMatrix(testDataPlus3,0,0);      
+        m.setSubMatrix(testDataPlus3,0,0);
         expected = MatrixUtils.createBigMatrix
         (new double[][] {{3.0,4.0,5.0},{4.0,7.0,5.0},{3.0,2.0,10.0}});
-        assertEquals(expected, m);   
-        
+        assertEquals(expected, m);
+
         // javadoc example
         BigMatrixImpl matrix = (BigMatrixImpl) MatrixUtils.createBigMatrix
             (new double[][] {{1, 2, 3, 4}, {5, 6, 7, 8}, {9, 0, 1 , 2}});
@@ -718,16 +710,16 @@ public final class BigMatrixImplTest extends TestCase {
              new BigDecimal(3), new BigDecimal(4), new BigDecimal(8)},
              {new BigDecimal(9), new BigDecimal(5) , new BigDecimal(6),
               new BigDecimal(2)}});
-        assertEquals(expected, matrix);   
-        
+        assertEquals(expected, matrix);
+
         // dimension overflow
-        try {  
+        try {
             m.setSubMatrix(matrix.getData(),1,1);
             fail("expecting MatrixIndexException");
         } catch (MatrixIndexException e) {
             // expected
         }
-        
+
         // null
         try {
             m.setSubMatrix(null,1,1);
@@ -735,7 +727,7 @@ public final class BigMatrixImplTest extends TestCase {
         } catch (NullPointerException e) {
             // expected
         }
-        
+
         // ragged
         try {
             m.setSubMatrix(new BigDecimal[][] {{new BigDecimal(1)},
@@ -744,7 +736,7 @@ public final class BigMatrixImplTest extends TestCase {
         } catch (IllegalArgumentException e) {
             // expected
         }
-        
+
         // empty
         try {
             m.setSubMatrix(new BigDecimal[][] {{}}, 0, 0);
@@ -752,17 +744,17 @@ public final class BigMatrixImplTest extends TestCase {
         } catch (IllegalArgumentException e) {
             // expected
         }
-        
+
     }
-    
+
     //--------------- -----------------Protected methods
-        
-    /** verifies that two matrices are close (1-norm) */              
+
+    /** verifies that two matrices are close (1-norm) */
     protected void assertClose(String msg, BigMatrix m, BigMatrix n,
         double tolerance) {
         assertTrue(msg,m.subtract(n).getNorm().doubleValue() < tolerance);
     }
-    
+
     /** verifies that two vectors are close (sup norm) */
     protected void assertClose(String msg, double[] m, double[] n,
         double tolerance) {
@@ -770,18 +762,18 @@ public final class BigMatrixImplTest extends TestCase {
             fail("vectors not same length");
         }
         for (int i = 0; i < m.length; i++) {
-            assertEquals(msg + " " +  i + " elements differ", 
+            assertEquals(msg + " " +  i + " elements differ",
                 m[i],n[i],tolerance);
         }
     }
-    
+
     /** extracts the l  and u matrices from compact lu representation */
     protected void splitLU(BigMatrix lu, BigDecimal[][] lowerData, BigDecimal[][] upperData) throws InvalidMatrixException {
         if (!lu.isSquare() || lowerData.length != lowerData[0].length || upperData.length != upperData[0].length ||
                 lowerData.length != upperData.length
                 || lowerData.length != lu.getRowDimension()) {
             throw new InvalidMatrixException("incorrect dimensions");
-        }    
+        }
         int n = lu.getRowDimension();
         for (int i = 0; i < n; i++) {
             for (int j = 0; j < n; j++) {
@@ -794,11 +786,11 @@ public final class BigMatrixImplTest extends TestCase {
                 } else {
                     lowerData[i][j] = new BigDecimal(0);
                     upperData[i][j] = lu.getEntry(i, j);
-                }   
+                }
             }
         }
     }
-    
+
     /** Returns the result of applying the given row permutation to the matrix */
     protected BigMatrix permuteRows(BigMatrix matrix, int[] permutation) {
         if (!matrix.isSquare() || matrix.getRowDimension() != permutation.length) {
@@ -814,7 +806,7 @@ public final class BigMatrixImplTest extends TestCase {
         }
         return new BigMatrixImpl(out);
     }
-    
+
     /** Extracts l and u matrices from lu and verifies that matrix = l times u modulo permutation */
     protected void verifyDecomposition(BigMatrix matrix, BigMatrix lu) throws Exception{
         int n = matrix.getRowDimension();
@@ -828,7 +820,7 @@ public final class BigMatrixImplTest extends TestCase {
         assertClose("lu decomposition does not work", permuted,
                 lower.multiply(upper), normTolerance);
     }
-         
+
 //    /** Useful for debugging */
 //    private void dumpMatrix(BigMatrix m) {
 //          for (int i = 0; i < m.getRowDimension(); i++) {
@@ -839,6 +831,6 @@ public final class BigMatrixImplTest extends TestCase {
 //              System.out.println(os);
 //          }
 //    }
-        
+
 }
 
