@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -17,26 +17,28 @@
 package org.apache.commons.math.linear;
 
 import java.io.Serializable;
+import java.util.Iterator;
 
-import junit.framework.Test;
 import junit.framework.TestCase;
-import junit.framework.TestSuite;
 
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.analysis.UnivariateRealFunction;
 
 /**
  * Test cases for the {@link OpenMapRealVector} class.
  *
- * @version $Revision: 799857 $ $Date: 2009-08-01 09:07:12 -0400 (Sat, 01 Aug 2009) $
+ * @version $Revision: 902203 $ $Date: 2010-01-22 13:27:41 -0500 (Fri, 22 Jan 2010) $
  */
 public class SparseRealVectorTest extends TestCase {
 
-    // 
+    //
     protected double[][] ma1 = {{1d, 2d, 3d}, {4d, 5d, 6d}, {7d, 8d, 9d}};
     protected double[] vec1 = {1d, 2d, 3d};
     protected double[] vec2 = {4d, 5d, 6d};
     protected double[] vec3 = {7d, 8d, 9d};
     protected double[] vec4 = {1d, 2d, 3d, 4d, 5d, 6d, 7d, 8d, 9d};
+    protected double[] vec5 = { -4d, 0d, 3d, 1d, -6d, 3d};
     protected double[] vec_null = {0d, 0d, 0d};
     protected Double[] dvec1 = {1d, 2d, 3d, 4d, 5d, 6d, 7d, 8d, 9d};
     protected double[][] mat1 = {{1d, 2d, 3d}, {4d, 5d, 6d},{ 7d, 8d, 9d}};
@@ -45,13 +47,11 @@ public class SparseRealVectorTest extends TestCase {
     protected double entryTolerance = 10E-16;
     protected double normTolerance = 10E-14;
 
-    // Testclass to test the RealVector interface 
+    // Testclass to test the RealVector interface
     // only with enough content to support the test
-    public static class SparseRealVectorTestImpl implements RealVector, Serializable {
-
-        /** Serializable version identifier. */
-        private static final long serialVersionUID = 4715341047369582908L;
+    public static class SparseRealVectorTestImpl extends AbstractRealVector implements Serializable {
 
+        private static final long serialVersionUID = -6251371752518113791L;
         /** Entries of the vector. */
         protected double data[];
 
@@ -63,42 +63,67 @@ public class SparseRealVectorTest extends TestCase {
             return new UnsupportedOperationException("Not supported, unneeded for test purposes");
         }
 
-        public RealVector copy() {
+        @Override
+        public RealVector map(UnivariateRealFunction function) throws FunctionEvaluationException {
             throw unsupported();
         }
 
+        @Override
+        public RealVector mapToSelf(UnivariateRealFunction function) throws FunctionEvaluationException {
+            throw unsupported();
+        }
+
+        @Override
+        public Iterator<Entry> iterator() {
+            throw unsupported();
+        }
+
+        @Override
+        public AbstractRealVector copy() {
+            return new SparseRealVectorTestImpl(data);
+        }
+
+        @Override
         public RealVector add(RealVector v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public RealVector add(double[] v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public RealVector subtract(RealVector v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public RealVector subtract(double[] v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAdd(double d) {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAddToSelf(double d) {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSubtract(double d) {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSubtractToSelf(double d) {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapMultiply(double d) {
             double[] out = new double[data.length];
             for (int i = 0; i < data.length; i++) {
@@ -107,206 +132,257 @@ public class SparseRealVectorTest extends TestCase {
             return new OpenMapRealVector(out);
         }
 
+        @Override
         public RealVector mapMultiplyToSelf(double d) {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapDivide(double d) {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapDivideToSelf(double d) {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapPow(double d) {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapPowToSelf(double d) {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapExp() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapExpToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapExpm1() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapExpm1ToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapLog() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapLogToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapLog10() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapLog10ToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapLog1p() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapLog1pToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapCosh() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapCoshToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSinh() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSinhToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapTanh() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapTanhToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapCos() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapCosToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSin() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSinToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapTan() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapTanToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAcos() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAcosToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAsin() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAsinToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAtan() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAtanToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapInv() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapInvToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAbs() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapAbsToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSqrt() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSqrtToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapCbrt() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapCbrtToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapCeil() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapCeilToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapFloor() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapFloorToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapRint() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapRintToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSignum() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapSignumToSelf() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapUlp() {
             throw unsupported();
         }
 
+        @Override
         public RealVector mapUlpToSelf() {
             throw unsupported();
         }
@@ -315,6 +391,7 @@ public class SparseRealVectorTest extends TestCase {
             throw unsupported();
         }
 
+        @Override
         public RealVector ebeMultiply(double[] v) throws IllegalArgumentException {
             throw unsupported();
         }
@@ -323,14 +400,17 @@ public class SparseRealVectorTest extends TestCase {
             throw unsupported();
         }
 
+        @Override
         public RealVector ebeDivide(double[] v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public double[] getData() {
             return data.clone();
         }
 
+        @Override
         public double dotProduct(RealVector v) throws IllegalArgumentException {
             double dot = 0;
             for (int i = 0; i < data.length; i++) {
@@ -339,6 +419,7 @@ public class SparseRealVectorTest extends TestCase {
             return dot;
         }
 
+        @Override
         public double dotProduct(double[] v) throws IllegalArgumentException {
             double dot = 0;
             for (int i = 0; i < data.length; i++) {
@@ -347,46 +428,57 @@ public class SparseRealVectorTest extends TestCase {
             return dot;
         }
 
+        @Override
         public double getNorm() {
             throw unsupported();
         }
 
+        @Override
         public double getL1Norm() {
             throw unsupported();
         }
 
+        @Override
         public double getLInfNorm() {
             throw unsupported();
         }
 
+        @Override
         public double getDistance(RealVector v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public double getDistance(double[] v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public double getL1Distance(RealVector v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public double getL1Distance(double[] v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public double getLInfDistance(RealVector v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public double getLInfDistance(double[] v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public RealVector unitVector() {
             throw unsupported();
         }
 
+        @Override
         public void unitize() {
             throw unsupported();
         }
@@ -395,14 +487,17 @@ public class SparseRealVectorTest extends TestCase {
             throw unsupported();
         }
 
+        @Override
         public RealVector projection(double[] v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public RealMatrix outerProduct(RealVector v) throws IllegalArgumentException {
             throw unsupported();
         }
 
+        @Override
         public RealMatrix outerProduct(double[] v) throws IllegalArgumentException {
             throw unsupported();
         }
@@ -432,21 +527,25 @@ public class SparseRealVectorTest extends TestCase {
         }
 
         public void setEntry(int index, double value) throws MatrixIndexException {
-            throw unsupported();
+            data[index] = value;
         }
 
+        @Override
         public void setSubVector(int index, RealVector v) throws MatrixIndexException {
             throw unsupported();
         }
 
+        @Override
         public void setSubVector(int index, double[] v) throws MatrixIndexException {
             throw unsupported();
         }
 
+        @Override
         public void set(double value) {
             throw unsupported();
         }
 
+        @Override
         public double[] toArray() {
             throw unsupported();
         }
@@ -461,12 +560,6 @@ public class SparseRealVectorTest extends TestCase {
 
     }
 
-    public static Test suite() {
-        TestSuite suite = new TestSuite(SparseRealVectorTest.class);
-        suite.setName("SparseRealVector Tests");
-        return suite;
-    }
-
     public void testConstructors() {
 
         OpenMapRealVector v0 = new OpenMapRealVector();
@@ -521,7 +614,7 @@ public class SparseRealVectorTest extends TestCase {
         OpenMapRealVector v1 = new OpenMapRealVector(vec1);
         OpenMapRealVector v2 = new OpenMapRealVector(vec2);
         OpenMapRealVector v4 = new OpenMapRealVector(vec4);
-        SparseRealVectorTestImpl v2_t = new SparseRealVectorTestImpl(vec2); 
+        SparseRealVectorTestImpl v2_t = new SparseRealVectorTestImpl(vec2);
 
         RealVector v_append_1 = v1.append(v2);
         assertEquals("testData len", 6, v_append_1.getDimension());
@@ -535,10 +628,10 @@ public class SparseRealVectorTest extends TestCase {
         assertEquals("testData len", 6, v_append_3.getDimension());
         assertEquals("testData is  ", 4.0, v_append_3.getEntry(3));
 
-	    RealVector v_append_4 = v1.append(v2_t);
+        RealVector v_append_4 = v1.append(v2_t);
         assertEquals("testData len", 6, v_append_4.getDimension());
         assertEquals("testData is 4.0 ", 4.0, v_append_4.getEntry(3));
-        
+
         RealVector vout5 = v4.getSubVector(3, 3);
         assertEquals("testData len", 3, vout5.getDimension());
         assertEquals("testData is 4.0 ", 5.0, vout5.getEntry(1));
@@ -551,7 +644,7 @@ public class SparseRealVectorTest extends TestCase {
             fail("wrong exception caught");
         }
 
-        OpenMapRealVector v_set1 = (OpenMapRealVector) v1.copy();
+        OpenMapRealVector v_set1 = v1.copy();
         v_set1.setEntry(1, 11.0);
         assertEquals("testData is 11.0 ", 11.0, v_set1.getEntry(1));
         try {
@@ -563,7 +656,7 @@ public class SparseRealVectorTest extends TestCase {
             fail("wrong exception caught");
         }
 
-        OpenMapRealVector v_set2 = (OpenMapRealVector) v4.copy();
+        OpenMapRealVector v_set2 = v4.copy();
         v_set2.setSubVector(3, v1);
         assertEquals("testData is 1.0 ", 1.0, v_set2.getEntry(3));
         assertEquals("testData is 7.0 ", 7.0, v_set2.getEntry(6));
@@ -576,7 +669,7 @@ public class SparseRealVectorTest extends TestCase {
             fail("wrong exception caught");
         }
 
-        OpenMapRealVector v_set3 = (OpenMapRealVector) v1.copy();
+        OpenMapRealVector v_set3 = v1.copy();
         v_set3.set(13.0);
         assertEquals("testData is 13.0 ", 13.0, v_set3.getEntry(2));
 
@@ -589,7 +682,7 @@ public class SparseRealVectorTest extends TestCase {
             fail("wrong exception caught");
         }
 
-        OpenMapRealVector v_set4 = (OpenMapRealVector) v4.copy();
+        OpenMapRealVector v_set4 = v4.copy();
         v_set4.setSubVector(3, v2_t);
         assertEquals("testData is 1.0 ", 4.0, v_set4.getEntry(3));
         assertEquals("testData is 7.0 ", 7.0, v_set4.getEntry(6));
@@ -605,7 +698,7 @@ public class SparseRealVectorTest extends TestCase {
 
     }
 
-    public void testMapFunctions() { 
+    public void testMapFunctions() {
         OpenMapRealVector v1 = new OpenMapRealVector(vec1);
 
         //octave =  v1 .+ 2.0
@@ -806,7 +899,7 @@ public class SparseRealVectorTest extends TestCase {
 
         //octave =  asin(vat)
         RealVector v_mapAsinToSelf = vat.copy();
-        v_mapAsinToSelf.mapAsinToSelf();        
+        v_mapAsinToSelf.mapAsinToSelf();
         double[] result_mapAsinToSelf = {0.0d,5.235987755982989e-01d,1.570796326794897e+00d};
         assertClose("compare vectors" ,result_mapAsinToSelf,v_mapAsinToSelf.getData(),normTolerance);
 
@@ -933,22 +1026,25 @@ public class SparseRealVectorTest extends TestCase {
 
     }
 
-    public void testBasicFunctions() { 
+    public void testBasicFunctions() {
         OpenMapRealVector v1 = new OpenMapRealVector(vec1);
         OpenMapRealVector v2 = new OpenMapRealVector(vec2);
+        OpenMapRealVector v5 = new OpenMapRealVector(vec5);
         OpenMapRealVector v_null = new OpenMapRealVector(vec_null);
 
-        SparseRealVectorTestImpl v2_t = new SparseRealVectorTestImpl(vec2); 
+        SparseRealVectorTestImpl v2_t = new SparseRealVectorTestImpl(vec2);
 
-        //octave =  sqrt(sumsq(v1))
-        double d_getNorm = v1.getNorm();
-        assertEquals("compare values  ", 3.7416573867739413,d_getNorm);
+        // emacs calc: [-4, 0, 3, 1, -6, 3] A --> 8.4261497731763586307
+        double d_getNorm = v5.getNorm();
+        assertEquals("compare values  ", 8.4261497731763586307, d_getNorm);
 
-        double d_getL1Norm = v1.getL1Norm();
-        assertEquals("compare values  ",6.0, d_getL1Norm);
+        // emacs calc: [-4, 0, 3, 1, -6, 3] vN --> 17
+        double d_getL1Norm = v5.getL1Norm();
+        assertEquals("compare values  ", 17.0, d_getL1Norm);
 
-        double d_getLInfNorm = v1.getLInfNorm();
-        assertEquals("compare values  ",6.0, d_getLInfNorm);
+        // emacs calc: [-4, 0, 3, 1, -6, 3] vn --> 6
+        double d_getLInfNorm = v5.getLInfNorm();
+        assertEquals("compare values  ", 6.0, d_getLInfNorm);
 
         //octave =  sqrt(sumsq(v1-v2))
         double dist = v1.getDistance(v2);
@@ -1024,7 +1120,7 @@ public class SparseRealVectorTest extends TestCase {
         assertEquals("compare val ",4d, m_outerProduct_2.getEntry(0,0));
 
         RealVector v_unitVector = v1.unitVector();
-        RealVector v_unitVector_2 = v1.mapDivide(v1.getNorm()); 
+        RealVector v_unitVector_2 = v1.mapDivide(v1.getNorm());
         assertClose("compare vect" ,v_unitVector.getData(),v_unitVector_2.getData(),normTolerance);
 
         try {
@@ -1036,7 +1132,7 @@ public class SparseRealVectorTest extends TestCase {
             fail("wrong exception caught");
         }
 
-        OpenMapRealVector v_unitize = (OpenMapRealVector)v1.copy();
+        OpenMapRealVector v_unitize = v1.copy();
         v_unitize.unitize();
         assertClose("compare vect" ,v_unitVector_2.getData(),v_unitize.getData(),normTolerance);
         try {
@@ -1056,21 +1152,21 @@ public class SparseRealVectorTest extends TestCase {
         double[] result_projection_2 = {1.662337662337662, 2.0779220779220777, 2.493506493506493};
         assertClose("compare vect", v_projection_2.getData(), result_projection_2, normTolerance);
 
-    }  
+    }
 
-    public void testMisc() { 
+    public void testMisc() {
         OpenMapRealVector v1 = new OpenMapRealVector(vec1);
 
         String out1 = v1.toString();
         assertTrue("some output ",  out1.length()!=0);
         try {
-            v1.checkVectorDimensions(2); 
+            v1.checkVectorDimensions(2);
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
         } catch (Exception e) {
             fail("wrong exception caught");
-        }     
+        }
 
 
     }
@@ -1100,7 +1196,7 @@ public class SparseRealVectorTest extends TestCase {
         OpenMapRealVector v = new OpenMapRealVector(new double[] { 0, 1, 2 });
         assertEquals(v,TestUtils.serializeAndRecover(v));
     }
-    
+
     /** verifies that two vectors are close (sup norm) */
     protected void assertClose(String msg, double[] m, double[] n,
             double tolerance) {
