@@ -22,9 +22,7 @@ import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Arrays;
 
-import junit.framework.Test;
 import junit.framework.TestCase;
-import junit.framework.TestSuite;
 
 import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.analysis.DifferentiableMultivariateVectorialFunction;
@@ -39,7 +37,7 @@ import org.apache.commons.math.optimization.VectorialPointValuePair;
 /**
  * <p>Some of the unit tests are re-implementations of the MINPACK <a
  * href="http://www.netlib.org/minpack/ex/file17">file17</a> and <a
- * href="http://www.netlib.org/minpack/ex/file22">file22</a> test files. 
+ * href="http://www.netlib.org/minpack/ex/file22">file22</a> test files.
  * The redistribution policy for MINPACK is available <a
  * href="http://www.netlib.org/minpack/disclaimer">here</a>, for
  * convenience, it is reproduced below.</p>
@@ -551,8 +549,8 @@ extends TestCase {
             for (int i = 0; i < n; ++i) {
                 Point2D.Double pi = points.get(i);
                 double di   = pi.distance(center);
-                jacobian[i][0] = (center.x - pi.x) / di - dRdX;    
-                jacobian[i][1] = (center.y - pi.y) / di - dRdY;    
+                jacobian[i][0] = (center.x - pi.x) / di - dRdX;
+                jacobian[i][1] = (center.y - pi.y) / di - dRdY;
            }
 
             return jacobian;
@@ -584,8 +582,4 @@ extends TestCase {
 
     }
 
-    public static Test suite() {
-        return new TestSuite(GaussNewtonOptimizerTest.class);
-    }
-
 }
