@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,13 +15,11 @@
  * limitations under the License.
  */
 package org.apache.commons.math.stat.inference;
-import junit.framework.Test;
-import junit.framework.TestSuite;
 
 /**
  * Test cases for the TTestTestFactory.
  *
- * @version $Revision: 762087 $ $Date: 2009-04-05 10:20:18 -0400 (Sun, 05 Apr 2009) $
+ * @version $Revision: 902201 $ $Date: 2010-01-22 13:18:16 -0500 (Fri, 22 Jan 2010) $
  */
 
 public class TTestFactoryTest extends TTestTest {
@@ -32,13 +30,8 @@ public class TTestFactoryTest extends TTestTest {
 
     @Override
     public void setUp() {
-    	super.setUp();
+        super.setUp();
         testStatistic = TestUtils.getTTest();
     }
 
-    public static Test suite() {
-        TestSuite suite = new TestSuite(TTestFactoryTest.class);
-        suite.setName("TTestFactory Tests");
-        return suite;
-    }
 }
