@@ -20,16 +20,14 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import junit.framework.Test;
 import junit.framework.TestCase;
-import junit.framework.TestSuite;
 
-import org.apache.commons.math.random.RandomDataImpl;
 import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.random.RandomDataImpl;
 
 /**
  * Test cases for the MathUtils class.
- * @version $Revision: 790243 $ $Date: 2007-08-16 15:36:33 -0500 (Thu, 16 Aug
+ * @version $Revision: 927009 $ $Date: 2007-08-16 15:36:33 -0500 (Thu, 16 Aug
  *          2007) $
  */
 public final class MathUtilsTest extends TestCase {
@@ -38,12 +36,6 @@ public final class MathUtilsTest extends TestCase {
         super(name);
     }
 
-    public static Test suite() {
-        TestSuite suite = new TestSuite(MathUtilsTest.class);
-        suite.setName("MathUtils Tests");
-        return suite;
-    }
-
     /** cached binomial coefficients */
     private static final List<Map<Integer, Long>> binomialCache = new ArrayList<Map<Integer, Long>>();
 
@@ -311,7 +303,7 @@ public final class MathUtilsTest extends TestCase {
       assertTrue(MathUtils.compareTo(152.308, 152.32, .011) < 0);
       assertTrue(MathUtils.compareTo(152.33, 152.318, .011) > 0);
     }
-    
+
     public void testCosh() {
         double x = 3.0;
         double expected = 10.06766;
@@ -361,7 +353,7 @@ public final class MathUtilsTest extends TestCase {
         assertFalse(MathUtils.equals(153, 153.00000000000006, 1));
         assertTrue(MathUtils.equals(153, 152.99999999999997, 1));
         assertFalse(MathUtils.equals(153, 152.99999999999994, 1));
-        
+
         assertTrue(MathUtils.equals(-128, -127.99999999999999, 1));
         assertFalse(MathUtils.equals(-128, -127.99999999999997, 1));
         assertTrue(MathUtils.equals(-128, -128.00000000000003, 1));
@@ -378,7 +370,7 @@ public final class MathUtilsTest extends TestCase {
 
         assertFalse(MathUtils.equals(Double.NEGATIVE_INFINITY, Double.POSITIVE_INFINITY, 100000));
     }
-    
+
     public void testArrayEquals() {
         assertFalse(MathUtils.equals(new double[] { 1d }, null));
         assertFalse(MathUtils.equals(null, new double[] { 1d }));
@@ -406,7 +398,7 @@ public final class MathUtilsTest extends TestCase {
             assertEquals(i + "! ", factorial(i), MathUtils.factorialDouble(i), Double.MIN_VALUE);
             assertEquals(i + "! ", Math.log(factorial(i)), MathUtils.factorialLog(i), 10E-12);
         }
-        
+
         assertEquals("0", 1, MathUtils.factorial(0));
         assertEquals("0", 1.0d, MathUtils.factorialDouble(0), 1E-14);
         assertEquals("0", 0.0d, MathUtils.factorialLog(0), 1E-14);
@@ -490,6 +482,81 @@ public final class MathUtilsTest extends TestCase {
         }
     }
 
+    public void  testGcdLong(){
+        long a = 30;
+        long b = 50;
+        long c = 77;
+
+        assertEquals(0, MathUtils.gcd(0L, 0));
+
+        assertEquals(b, MathUtils.gcd(0, b));
+        assertEquals(a, MathUtils.gcd(a, 0));
+        assertEquals(b, MathUtils.gcd(0, -b));
+        assertEquals(a, MathUtils.gcd(-a, 0));
+
+        assertEquals(10, MathUtils.gcd(a, b));
+        assertEquals(10, MathUtils.gcd(-a, b));
+        assertEquals(10, MathUtils.gcd(a, -b));
+        assertEquals(10, MathUtils.gcd(-a, -b));
+
+        assertEquals(1, MathUtils.gcd(a, c));
+        assertEquals(1, MathUtils.gcd(-a, c));
+        assertEquals(1, MathUtils.gcd(a, -c));
+        assertEquals(1, MathUtils.gcd(-a, -c));
+
+        assertEquals(3L * (1L<<45), MathUtils.gcd(3L * (1L<<50), 9L * (1L<<45)));
+
+        assertEquals(1L<<45, MathUtils.gcd(1L<<45, Long.MIN_VALUE));
+
+        assertEquals(Long.MAX_VALUE, MathUtils.gcd(Long.MAX_VALUE, 0L));
+        assertEquals(Long.MAX_VALUE, MathUtils.gcd(-Long.MAX_VALUE, 0L));
+        assertEquals(1, MathUtils.gcd(60247241209L, 153092023L));
+        try {
+            // gcd(Long.MIN_VALUE, 0) > Long.MAX_VALUE
+            MathUtils.gcd(Long.MIN_VALUE, 0);
+            fail("expecting ArithmeticException");
+        } catch (ArithmeticException expected) {
+            // expected
+        }
+        try {
+            // gcd(0, Long.MIN_VALUE) > Long.MAX_VALUE
+            MathUtils.gcd(0, Long.MIN_VALUE);
+            fail("expecting ArithmeticException");
+        } catch (ArithmeticException expected) {
+            // expected
+        }
+        try {
+            // gcd(Long.MIN_VALUE, Long.MIN_VALUE) > Long.MAX_VALUE
+            MathUtils.gcd(Long.MIN_VALUE, Long.MIN_VALUE);
+            fail("expecting ArithmeticException");
+        } catch (ArithmeticException expected) {
+            // expected
+        }
+    }
+
+    public void testGcdConsistency() {
+        int[] primeList = {19, 23, 53, 67, 73, 79, 101, 103, 111, 131};
+        ArrayList<Integer> primes = new ArrayList<Integer>();
+        for (int i = 0; i < primeList.length; i++) {
+            primes.add(Integer.valueOf(primeList[i]));
+        }
+        RandomDataImpl randomData = new RandomDataImpl();
+        for (int i = 0; i < 20; i++) {
+            Object[] sample = randomData.nextSample(primes, 4);
+            int p1 = ((Integer) sample[0]).intValue();
+            int p2 = ((Integer) sample[1]).intValue();
+            int p3 = ((Integer) sample[2]).intValue();
+            int p4 = ((Integer) sample[3]).intValue();
+            int i1 = p1 * p2 * p3;
+            int i2 = p1 * p2 * p4;
+            int gcd = p1 * p2;
+            assertEquals(gcd, MathUtils.gcd(i1, i2));
+            long l1 = i1;
+            long l2 = i2;
+            assertEquals(gcd, MathUtils.gcd(l1, l2));
+        }
+    }
+
     public void testHash() {
         double[] testArray = {
             Double.NaN,
@@ -529,7 +596,7 @@ public final class MathUtilsTest extends TestCase {
         assertFalse(MathUtils.hash(new double[] { 1d }) ==
                     MathUtils.hash(new double[] { 1d, 1d }));
     }
-    
+
     /**
      * Make sure that permuted arrays do not hash to the same value.
      */
@@ -537,12 +604,12 @@ public final class MathUtilsTest extends TestCase {
         double[] original = new double[10];
         double[] permuted = new double[10];
         RandomDataImpl random = new RandomDataImpl();
-        
+
         // Generate 10 distinct random values
         for (int i = 0; i < 10; i++) {
             original[i] = random.nextUniform(i + 0.5, i + 0.75);
         }
-        
+
         // Generate a random permutation, making sure it is not the identity
         boolean isIdentity = true;
         do {
@@ -554,7 +621,7 @@ public final class MathUtilsTest extends TestCase {
                 permuted[i] = original[permutation[i]];
             }
         } while (isIdentity);
-        
+
         // Verify that permuted array has different hash
         assertFalse(MathUtils.hash(original) == MathUtils.hash(permuted));
     }
@@ -624,22 +691,72 @@ public final class MathUtilsTest extends TestCase {
             // lcm == abs(MIN_VALUE) cannot be represented as a nonnegative int
             MathUtils.lcm(Integer.MIN_VALUE, 1);
             fail("Expecting ArithmeticException");
-        } catch (ArithmeticException ex) {
+        } catch (ArithmeticException expected) {
             // expected
         }
-        
+
         try {
             // lcm == abs(MIN_VALUE) cannot be represented as a nonnegative int
             MathUtils.lcm(Integer.MIN_VALUE, 1<<20);
             fail("Expecting ArithmeticException");
-        } catch (ArithmeticException ex) {
+        } catch (ArithmeticException expected) {
             // expected
         }
 
         try {
             MathUtils.lcm(Integer.MAX_VALUE, Integer.MAX_VALUE - 1);
             fail("Expecting ArithmeticException");
-        } catch (ArithmeticException ex) {
+        } catch (ArithmeticException expected) {
+            // expected
+        }
+    }
+
+    public void testLcmLong() {
+        long a = 30;
+        long b = 50;
+        long c = 77;
+
+        assertEquals(0, MathUtils.lcm(0, b));
+        assertEquals(0, MathUtils.lcm(a, 0));
+        assertEquals(b, MathUtils.lcm(1, b));
+        assertEquals(a, MathUtils.lcm(a, 1));
+        assertEquals(150, MathUtils.lcm(a, b));
+        assertEquals(150, MathUtils.lcm(-a, b));
+        assertEquals(150, MathUtils.lcm(a, -b));
+        assertEquals(150, MathUtils.lcm(-a, -b));
+        assertEquals(2310, MathUtils.lcm(a, c));
+
+        assertEquals(Long.MAX_VALUE, MathUtils.lcm(60247241209L, 153092023L));
+
+        // Assert that no intermediate value overflows:
+        // The naive implementation of lcm(a,b) would be (a*b)/gcd(a,b)
+        assertEquals((1L<<50)*15, MathUtils.lcm((1L<<45)*3, (1L<<50)*5));
+
+        // Special case
+        assertEquals(0L, MathUtils.lcm(0L, 0L));
+
+        try {
+            // lcm == abs(MIN_VALUE) cannot be represented as a nonnegative int
+            MathUtils.lcm(Long.MIN_VALUE, 1);
+            fail("Expecting ArithmeticException");
+        } catch (ArithmeticException expected) {
+            // expected
+        }
+
+        try {
+            // lcm == abs(MIN_VALUE) cannot be represented as a nonnegative int
+            MathUtils.lcm(Long.MIN_VALUE, 1<<20);
+            fail("Expecting ArithmeticException");
+        } catch (ArithmeticException expected) {
+            // expected
+        }
+
+        assertEquals((long) Integer.MAX_VALUE * (Integer.MAX_VALUE - 1),
+            MathUtils.lcm((long)Integer.MAX_VALUE, Integer.MAX_VALUE - 1));
+        try {
+            MathUtils.lcm(Long.MAX_VALUE, Long.MAX_VALUE - 1);
+            fail("Expecting ArithmeticException");
+        } catch (ArithmeticException expected) {
             // expected
         }
     }
@@ -797,6 +914,54 @@ public final class MathUtilsTest extends TestCase {
         }
     }
 
+    public void testNormalizeArray() {
+        double[] testValues1 = new double[] {1, 1, 2};
+        TestUtils.assertEquals(
+                new double[] {.25, .25, .5},
+                MathUtils.normalizeArray(testValues1, 1),
+                Double.MIN_VALUE);
+
+        double[] testValues2 = new double[] {-1, -1, 1};
+        TestUtils.assertEquals(
+                new double[] {1, 1, -1},
+                MathUtils.normalizeArray(testValues2, 1),
+                Double.MIN_VALUE);
+
+        // Ignore NaNs
+        double[] testValues3 = new double[] {-1, -1, Double.NaN, 1, Double.NaN};
+        TestUtils.assertEquals(
+                new double[] {1, 1,Double.NaN, -1, Double.NaN},
+                MathUtils.normalizeArray(testValues3, 1),
+                Double.MIN_VALUE);
+
+        // Zero sum -> ArithmeticException
+        double[] zeroSum = new double[] {-1, 1};
+        try {
+            MathUtils.normalizeArray(zeroSum, 1);
+            fail("expecting ArithmeticException");
+        } catch (ArithmeticException ex) {}
+
+        // Infinite elements -> ArithmeticException
+        double[] hasInf = new double[] {1, 2, 1, Double.NEGATIVE_INFINITY};
+        try {
+            MathUtils.normalizeArray(hasInf, 1);
+            fail("expecting ArithmeticException");
+        } catch (ArithmeticException ex) {}
+
+        // Infinite target -> IllegalArgumentException
+        try {
+            MathUtils.normalizeArray(testValues1, Double.POSITIVE_INFINITY);
+            fail("expecting IllegalArgumentException");
+        } catch (IllegalArgumentException ex) {}
+
+        // NaN target -> IllegalArgumentException
+        try {
+            MathUtils.normalizeArray(testValues1, Double.NaN);
+            fail("expecting IllegalArgumentException");
+        } catch (IllegalArgumentException ex) {}
+
+    }
+
     public void testRoundDouble() {
         double x = 1.234567890;
         assertEquals(1.23, MathUtils.round(x, 2), 0.0);
@@ -1177,7 +1342,7 @@ public final class MathUtilsTest extends TestCase {
         assertEquals(bigOne, MathUtils.pow(twentyOne, 103));
         assertEquals(bigOne, MathUtils.pow(twentyOne, 103l));
         assertEquals(bigOne, MathUtils.pow(twentyOne, BigInteger.valueOf(103l)));
-        
+
     }
 
     public void testL1DistanceDouble() {
@@ -1216,4 +1381,35 @@ public final class MathUtilsTest extends TestCase {
         assertEquals(4, MathUtils.distanceInf(p1, p2));
     }
 
+    public void testCheckOrder() {
+        MathUtils.checkOrder(new double[] {-15, -5.5, -1, 2, 15}, 1, true);
+        MathUtils.checkOrder(new double[] {-15, -5.5, -1, 2, 2}, 1, false);
+        MathUtils.checkOrder(new double[] {3, -5.5, -11, -27.5}, -1, true);
+        MathUtils.checkOrder(new double[] {3, 0, 0, -5.5, -11, -27.5}, -1, false);
+
+        try {
+            MathUtils.checkOrder(new double[] {-15, -5.5, -1, -1, 2, 15}, 1, true);
+            fail("an exception should have been thrown");
+        } catch (IllegalArgumentException e) {
+            // Expected
+        }
+        try {
+            MathUtils.checkOrder(new double[] {-15, -5.5, -1, -2, 2}, 1, false);
+            fail("an exception should have been thrown");
+        } catch (IllegalArgumentException e) {
+            // Expected
+        }
+        try {
+            MathUtils.checkOrder(new double[] {3, 3, -5.5, -11, -27.5}, -1, true);
+            fail("an exception should have been thrown");
+        } catch (IllegalArgumentException e) {
+            // Expected
+        }
+        try {
+            MathUtils.checkOrder(new double[] {3, -1, 0, -5.5, -11, -27.5}, -1, false);
+            fail("an exception should have been thrown");
+        } catch (IllegalArgumentException e) {
+            // Expected
+        }
+    }
 }
